﻿using System.Collections.Generic;
using System.Linq;

namespace TreeTraversal
{
    /// <summary>
    /// Assists in performing a depth-first traversal of nodes for some Node type T. 
    /// T need not be of any specific type.
    /// </summary>
    public struct DFSEvent<T>
    {
        public enum WalkEventType
        {
            Enter,
            Exit
        };

        public readonly WalkEventType EventType;
        public readonly T Node;
        public readonly int Depth;

        public DFSEvent(T node, WalkEventType eventEventType, int depth)
        {
            this.Node = node;
            this.EventType = eventEventType;
            this.Depth = depth;
        }

        public static DFSEvent<T> CreateEnterEvent(T node, int depth)
        {
            var we = new DFSEvent<T>(node, WalkEventType.Enter, depth );
            return we;
        }

        public static DFSEvent<T> CreateExitEvent(T node, int depth)
        {
            var we = new DFSEvent<T>(node, WalkEventType.Exit, depth);
            return we;
        }

        public bool HasEnteredNode
        {
            get { return this.EventType == WalkEventType.Enter; }
        }

        public bool HasExitedNode
        {
            get { return this.EventType == WalkEventType.Exit; }
        }
    }
}