﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Collections.Generic;
using TreeTraversal;
using System.Linq;

namespace TreeTraversalTest
{

    public class Node
    {
        public string Value;
        public List<Node> Children;

        public Node(string value)
        {
            this.Value = value;
            this.Children = new List<Node>();
        }

        public Node(string value, params Node[] childnodes)
        {
            this.Value = value;
            this.Children = new List<Node>(childnodes);
        }
    }

    
    [TestClass]
    public class UnitTest1
    {
        public static Node tree_2 = new Node("NorthAmerica",
                                        new Node("UnitedStates",
                                            new Node("Washington",
                                                new Node("Seattle"),
                                                new Node("Tacoma")
                                            ),
                                            new Node("Oregon")
                                        ),
                                        new Node("Canada",
                                            new Node("BritishColumbia"),
                                            new Node("Alberta")
                                        )
                                    );

        public static Node tree_3 = new Node("1",
                                        new Node("2"),
                                        new Node("3", 
                                                new Node("5",
                                                new Node("8"),
                                                new Node("9")
                                            ),
                                            new Node("6",
                                                new Node("10")
                                            )
),
                                        new Node("4",
                                            new Node("7"))
                                        );

        [TestMethod]
        public void TestMethod1()
        {
            var events = TreeTraversal.TreeTraversal.DFSWalk(tree_2, n => n.Children);

            var walklog = get_walk_log(events);

            Assert.AreEqual(18,walklog.Count);
            Assert.AreEqual("Enter 0 NorthAmerica", walklog[0]);
            Assert.AreEqual("Enter 1 UnitedStates", walklog[1]);
            Assert.AreEqual("Enter 2 Washington", walklog[2]);
            Assert.AreEqual("Enter 3 Seattle", walklog[3]);
            Assert.AreEqual("Exit 3 Seattle", walklog[4]);
            Assert.AreEqual("Enter 3 Tacoma", walklog[5]);
            Assert.AreEqual("Exit 3 Tacoma", walklog[6]);
            Assert.AreEqual("Exit 2 Washington", walklog[7]);
            Assert.AreEqual("Enter 2 Oregon", walklog[8]);
            Assert.AreEqual("Exit 2 Oregon", walklog[9]);
            Assert.AreEqual("Exit 1 UnitedStates", walklog[10]);
            Assert.AreEqual("Enter 1 Canada", walklog[11]);
            Assert.AreEqual("Enter 2 BritishColumbia", walklog[12]);
            Assert.AreEqual("Exit 2 BritishColumbia", walklog[13]);
            Assert.AreEqual("Enter 2 Alberta", walklog[14]);
            Assert.AreEqual("Exit 2 Alberta", walklog[15]);
            Assert.AreEqual("Exit 1 Canada", walklog[16]);
            Assert.AreEqual("Exit 0 NorthAmerica", walklog[17]);
        }

        [TestMethod]
        public void TestManualPreOrder()
        {
            var events = TreeTraversal.TreeTraversal.DFSWalk(tree_2, n => n.Children.Select(n2=>n2));

            var walklog= new List<string>();
            foreach (var ev in events.Where(e=>e.HasEnteredNode))
            {
                   walklog.Add(ev.Node.Value);
            }
            var output = string.Join(",", walklog);

            Assert.AreEqual(
                "NorthAmerica,UnitedStates,Washington,Seattle,Tacoma,Oregon,Canada,BritishColumbia,Alberta",output);

        }

        [TestMethod]
        public void TestManualPostOrder()
        {
            var events = TreeTraversal.TreeTraversal.DFSWalk(tree_2, n => n.Children);

            var walklog = new List<string>();
            foreach (var ev in events.Where(e => e.HasExitedNode))
            {
                walklog.Add(ev.Node.Value);
            }
            var output = string.Join(",", walklog);

            Assert.AreEqual(
                "Seattle,Tacoma,Washington,Oregon,UnitedStates,BritishColumbia,Alberta,Canada,NorthAmerica", output);

        }

        [TestMethod]
        public void TestWalkAtSpecificDepth()
        {
            var events = TreeTraversal.TreeTraversal.DFSWalk(tree_2, n => n.Children);

            var walklog = new List<string>();
            int depth = 0;
            foreach (var ev in events)
            {
                if (ev.HasEnteredNode && depth==2)
                {
                    walklog.Add(ev.Node.Value);
                }

                if (ev.HasEnteredNode)
                {
                    depth++;
                }
                else
                {
                    depth--;
                }

            }

            var output = string.Join(",", walklog);

            Assert.AreEqual(
                "Washington,Oregon,BritishColumbia,Alberta", output);

        }

        [TestMethod]
        public void TestPreOrderAndPostOrder()
        {
            // Sample data from here http://lcm.csa.iisc.ernet.in/dsa/node84.html

            var pre_nodes= TreeTraversal.TreeTraversal.PreOrder(tree_3, n => n.Children).Select(n => n.Value).ToList();
            var pre = string.Join(",", pre_nodes);

            Assert.AreEqual("1,2,3,5,8,9,6,10,4,7",pre);

            var post_nodes = TreeTraversal.TreeTraversal.PostOrder(tree_3, n => n.Children).Select(n => n.Value).ToList();
            var post = string.Join(",", post_nodes);

            Assert.AreEqual("2,8,9,5,10,6,3,7,4,1", post);
        }

        [TestMethod]
        public void TestBreadthFirstSearch()
        {
            var pre_nodes = TreeTraversal.TreeTraversal.BreadFirst(tree_3, n => n.Children).Select(n => n.Value).ToList();
            var pre = string.Join(",", pre_nodes);

            Assert.AreEqual("1,2,3,4,5,6,7,8,9,10", pre);
        }

        private static List<string> get_walk_log(IEnumerable<DFSEvent<Node>> events)
        {
            var walklog = new List<string>();
            foreach (var ev in events)
            {
                var s = string.Format("{0} {1} {2}", ev.EventType, ev.Depth, ev.Node.Value);
                walklog.Add(s);
            }
            return walklog;
        }
    }
}
