﻿using SXL = System.Xml.Linq;

namespace Viziblr.ColourLovers
{
    public class PaletteRequest
    {
        public PaletteRequest()
        {
            this.ListType = PaletteListType.New;
        }

        public PaletteListType ListType { get; set; }
        public int? ResultOffset { get; set; }
        public int? NumResults { get; set; }

        public string GetURL()
        {
            string listtype = null;
            switch (this.ListType)
            {
                case PaletteListType.Top:
                    {
                        listtype = "top";
                        break;
                    }
                case PaletteListType.New:
                    {
                        listtype = "new";
                        break;
                    }
                case PaletteListType.Random:
                    {
                        listtype = "random";
                        break;
                    }
                default:
                    {
                        new ColourLoversException("Unsupported List Type");
                        break;
                    }
            }

            var url_sb = new System.Text.StringBuilder();
            url_sb.AppendFormat("{0}//{1}", "http://www.colourlovers.com/api/palettes" ,listtype);

            if (this.ResultOffset.HasValue)
            {
                url_sb.AppendFormat("&resultOffset={0}",this.ResultOffset.Value.ToString(System.Globalization.CultureInfo.InvariantCulture));
            }

            if (this.NumResults.HasValue)
            {
                url_sb.AppendFormat("&numResults={0}", this.NumResults.Value.ToString(System.Globalization.CultureInfo.InvariantCulture));
            }

            var url = url_sb.ToString();
            return url;
        }

        public PalettesResult Execute()
        {
            string url = this.GetURL();
            var doc = SXL.XDocument.Load(url);

            var palette_el = doc.Root.Element("palette");
            if (palette_el == null)
            {
                throw new ColourLoversException("Missing <palette> element");
            }

            var palettelist = new PalettesResult();
            palettelist.Palettes.Clear();
            palettelist.Title = palette_el.Element("title").Value;
            palettelist.APIURL = palette_el.Element("apiUrl").Value;

            var palette_obj = ColourLovers.Palette.FromXmlElement(palette_el);
            palettelist.Palettes.Add(palette_obj);

            return palettelist;
        }
    }
}