using System.Linq;

namespace Viziblr.Drawing
{
    public class BezierCurve
    {
        public Point[] ControlPoints { get; set; }
        public int Degree { get; set; }

        public BezierCurve()
        {
            this.ControlPoints = null;
            this.Degree = -1;
        }

        public BezierCurve(Point[] points, int degree)
        {
            this.ControlPoints = points;
            this.Degree = degree;
        }

        public static BezierCurve FromEllipse(Point center, Size radius)
        {
            var curve = new BezierCurve();

            var pt1 = new Point(0, radius.Height); // top
            var pt2 = new Point(radius.Width, 0); // right
            var pt3 = new Point(0, -radius.Height); // bottom
            var pt4 = new Point(-radius.Width, 0); // left

            double dx = radius.Width * 4.0 * (System.Math.Sqrt(2) - 1) / 3;
            double dy = radius.Height * 4.0 * (System.Math.Sqrt(2) - 1) / 3;

            curve.ControlPoints = new Point[]
                                      {
                                          pt1,
                                          pt1.Add(dx, 0),
                                          pt2.Add(0, dy),
                                          pt2,
                                          pt2.Add(0, -dy),
                                          pt3.Add(dx, 0),
                                          pt3,
                                          pt3.Add(-dx, 0),
                                          pt4.Add(0, -dy),
                                          pt4,
                                          pt4.Add(0, dy),
                                          pt1.Add(-dx, 0),
                                          pt1
                                      }
                                      .Select(p => p + center).ToArray();

            curve.Degree = 3;

            return curve;
        }

        public static Point GetPointOnBezier(double t, Point start, Point handle0, Point handle1, Point end)
        {
            // found in this post: http://bytes.com/forum/thread734965.html
            // which takes it from: http://www.moshplant.com/direct-or/bezier/math.html
            double cx = 3 * (handle0.X - start.X);
            double bx = (3 * (handle1.X - handle0.X)) - cx;
            double ax = end.X - start.X - cx - bx;
            double cy = 3 * (handle0.Y - start.Y);
            double by = (3 * (handle1.Y - handle0.Y)) - cy;
            double ay = end.Y - start.Y - cy - by;
            double tCubed = t * t * t;
            double tSquared = t * t;
            double resultX = (ax * tCubed) + (bx * tSquared) + (cx * t) + start.X;
            double resultY = (ay * tCubed) + (by * tSquared) + (cy * t) + start.Y;

            return new Point(resultX, resultY);
        }
    }
}