using System.Collections.Generic;

namespace Viziblr.Drawing
{
    public struct Point
    {
        private readonly double _x;
        private readonly double _y;

        public Point(double x, double y)
        {
            _x = x;
            _y = y;
        }

        public double X
        {
            get { return _x; }
        }

        public double Y
        {
            get { return _y; }
        }

        public override string ToString()
        {
            var invariant_culture = System.Globalization.CultureInfo.InvariantCulture;
            string s = string.Format(invariant_culture, "Point({0}x{1})", _x, _y);
            return s;
        }

        public static Point operator -(Point pa, Point pb)
        {
            var result = new Point(pa._x - pb._x, pa._y - pb._y);
            return result;
        }

        public static Point operator +(Point pa, Point pb)
        {
            var result = new Point(pa._x + pb._x, pa._y + pb._y);
            return result;
        }


        public static Point operator *(Point pa, double s)
        {
            var result = new Point(pa._x*s, pa._y*s);
            return result;
        }


        public static Point operator *(Point pa, Size s)
        {
            var result = new Point(pa._x * s.Width , pa._y * s.Height );
            return result;
        }


        public double Length()
        {
            return System.Math.Sqrt((_x*_x) + (_y*_y));
        }

        public Point Add(double dx, double dy)
        {
            var new_point = new Point(_x + dx, _y + dy);
            return new_point;
        }

        public Point Subtract(double dx, double dy)
        {
            var new_point = new Point(_x - dx, _y - dy);
            return new_point;
        }

        public Point Add(Point p)
        {
            var new_point = new Point(_x + p._x, _y + p._y);
            return new_point;
        }

        public Point Subtract(Point p)
        {
            var new_point = new Point(_x - p._x, _y - p._y);
            return new_point;
        }

        public Point Add(Size s)
        {
            var new_point = new Point(_x + s.Width, _y + s.Height);
            return new_point;
        }

        public Point Subtract(Size s)
        {
            var new_point = new Point(_x - s.Width, _y - s.Height);
            return new_point;
        }

        public static Point operator *(Point pa, Point pb)
        {
            return pa.Multiply(pb._x, pb._y);
        }

        public Point Multiply(double s)
        {
            return Multiply(s, s);
        }

        public Point Multiply(double sx, double sy)
        {
            var new_point = new Point(_x*sx, _y*sy);
            return new_point;
        }

        public Point Multiply( Size s)
        {
            var new_point = new Point(_x * s.Width , _y * s.Height);
            return new_point;
        }

        public Point Divide(double sx, double sy)
        {
            var new_point = new Point(_x/sx, _y/sy);
            return new_point;
        }

        public Point Divide(double s)
        {
            return Divide(s, s);
        }

        public static IEnumerable<Point> DoublesToPoints(IEnumerable<double>doubles)
        {

            if (doubles == null)
            {
                throw new System.ArgumentNullException("values");
            }

            int count = 0;
            double even_value = default(double);
            foreach (var value in doubles)
            {
                if ((count % 2) == 0)
                {
                    even_value = value;
                }
                else
                {
                    yield return new Point(even_value, value);
                }
                count++;
            }
        }

        public static IEnumerable<double> PointsToDoubles(IEnumerable<Point> points)
        {
            foreach (var p in points)
            {
                yield return p._x;
                yield return p._y;
            }
        }

        public static Point Round(Point p, double xd, double yd)
        {
            return new Point(DrawingUtil.Round(p._x, xd),
                             DrawingUtil.Round(p._y, yd));
        }

        public static Point FromMidPoint(Point a, Point b)
        {
            double x = (a._x + b._x)/2.0;
            double y = (a._y + b._y)/2.0;
            return new Point(x, y);
        }
    }
}