using System.Collections.Generic;
using System.Linq;

namespace Isotope.Imaging.Quantization
{
    public class QuantizationUtil
    {
        public static IDictionary<int, int> CountDistictColors(
            System.Drawing.Bitmap bmp, 
            int max_colors,
            bool discard_alpha)
        {
            if (bmp==null)
            {
                throw new System.ArgumentNullException("bmp");
            }

            if (max_colors<2)
            {
                throw new System.ArgumentOutOfRangeException("max_colors");
            }

            var colors = colors_in_bmp(bmp);
            var color_dic = CountDistictColors(colors, max_colors, discard_alpha);
            return color_dic;
        }

        public static IDictionary<int, int> CountDistictColors(
                IEnumerable<int> colors,
                int max_colors,
                bool discard_alpha)
        {
            if (colors == null)
            {
                throw new System.ArgumentNullException("colors");
            }

            if (max_colors < 2)
            {
                throw new System.ArgumentOutOfRangeException("max_colors");
            }

            int alpha_mask = discard_alpha ? 0x00ffffff : 0xffffff;

            var color_dic = new Dictionary<int, int>();

            foreach (int rgb in colors)
            {
                var current_rgb = rgb & alpha_mask;
                int old_count;
                bool new_count = color_dic.TryGetValue(current_rgb, out old_count);
                color_dic[current_rgb] = new_count ? old_count + 1 : 1;
                
            }

            return color_dic;
        }

        private static IEnumerable<int> colors_in_bmp(System.Drawing.Bitmap bmp)
        {
            for (int x = 0; x < bmp.Width; x++)
            {
                for (int y = 0; y < bmp.Height; y++)
                {
                    yield return bmp.GetPixel(x, y).ToArgb();
                }
            }
        }

    }
}