﻿using System.Xml.Linq;

namespace Viziblr.Kuler
{
    public class Swatch
    {
        public SwatchColorMode ColorMode { get; set; }
        public string Index { get; set; }
        public double Channel1 { get; set; }
        public double Channel2 { get; set; }
        public double Channel3 { get; set; }
        public double Channel4 { get; set; }
        public string HexColor { get; set; }
        public int RGB { get; set; }

        public static Swatch FromXml(XElement swatch_el)
        {
            var swatch = new Swatch();

            string ModeString = swatch_el.Element(elname_swatchcolormode).Value;
            swatch.Index = swatch_el.Element(elname_swatchindex).Value;

            swatch.HexColor = swatch_el.Element(elname_swatchhexcolor).Value;
            swatch.RGB = System.Convert.ToInt32(swatch.HexColor, 16);

            swatch.Channel1 = swatch_el.ElementValueDouble(elname_swatchchannel1);
            swatch.Channel2 = swatch_el.ElementValueDouble(elname_swatchchannel2);
            swatch.Channel3 = swatch_el.ElementValueDouble(elname_swatchchannel3);
            swatch.Channel4 = swatch_el.ElementValueDouble(elname_swatchchannel4);

            if (ModeString == "rgb")
            {
                swatch.ColorMode = SwatchColorMode.RGB;
            }
            else if (ModeString == "hsv")
            {
                swatch.ColorMode = SwatchColorMode.HSV;
            }
            else if (ModeString == "cmyk")
            {
                swatch.ColorMode = SwatchColorMode.CMYK;
            }
            else if (ModeString == "lab")
            {
                swatch.ColorMode = SwatchColorMode.LAB;
            }
            else
            {
                string msg = string.Format("Unhandled color mode \"{0}\"", ModeString);
                throw new KulerException(msg);
            }

            return swatch;
        }

        const string elname_swatchcolormode = "{http://kuler.adobe.com/kuler/API/rss/}swatchColorMode";
        const string elname_swatchindex = "{http://kuler.adobe.com/kuler/API/rss/}swatchIndex";
        const string elname_swatchhexcolor = "{http://kuler.adobe.com/kuler/API/rss/}swatchHexColor";
        const string elname_swatchchannel1 = "{http://kuler.adobe.com/kuler/API/rss/}swatchChannel1";
        const string elname_swatchchannel2 = "{http://kuler.adobe.com/kuler/API/rss/}swatchChannel2";
        const string elname_swatchchannel3 = "{http://kuler.adobe.com/kuler/API/rss/}swatchChannel3";
        const string elname_swatchchannel4 = "{http://kuler.adobe.com/kuler/API/rss/}swatchChannel4";

    }
}