﻿using System.Linq;
using System.Xml.Linq;

namespace Viziblr.Kuler
{
    public class Theme
    {
        private static System.Globalization.CultureInfo nfo = new System.Globalization.CultureInfo("en-US");

        public string ID { get; set; }
        public string Title { get; set; }
        public string AuthorLabel { get; set; }
        public string AuthorID { get; set; }
        public System.DateTime CreatedAt { get; set; }
        public System.DateTime EditedAt { get; set; }
        public int Rating { get; set; }
        public Swatch[] Swatches { get; set; }

        public static Theme FromXmlElement(XElement theme_el)
        {
            var theme = new Theme();



            theme.ID = theme_el.ElementValue(elname_themeid);
            theme.Title = theme_el.ElementValue(elname_themetitle);
            var author_el = theme_el.Element(elname_themeauthor);
            theme.AuthorLabel = author_el.ElementValue(elname_authorlabel);
            theme.AuthorID = author_el.ElementValue(elname_authorid);
            theme.Rating = theme_el.ElementValueInt(elname_themerating);
            theme.CreatedAt = ConvertDateTimeString(theme_el.ElementValue(elname_themecreatedat));
            theme.EditedAt = ConvertDateTimeString(theme_el.ElementValue(elname_themeeditedat));

            theme.Swatches = theme_el.Descendants(elname_swatch)
                .Select(el => Swatch.FromXml(el))
                .ToArray();
            return theme;
        }

        private static System.DateTime ConvertDateTimeString(string dts)
        {
            var d = System.DateTime.ParseExact(dts, "yyyyMMdd", nfo);
            return d;
        }

        const string elname_themeid = "{http://kuler.adobe.com/kuler/API/rss/}themeID";
        const string elname_themetitle = "{http://kuler.adobe.com/kuler/API/rss/}themeTitle";
        const string elname_themeauthor = "{http://kuler.adobe.com/kuler/API/rss/}themeAuthor";
        const string elname_authorlabel = "{http://kuler.adobe.com/kuler/API/rss/}authorLabel";
        const string elname_authorid = "{http://kuler.adobe.com/kuler/API/rss/}authorID";
        const string elname_themerating = "{http://kuler.adobe.com/kuler/API/rss/}themeRating";
        const string elname_themecreatedat = "{http://kuler.adobe.com/kuler/API/rss/}themeCreatedAt";
        const string elname_themeeditedat = "{http://kuler.adobe.com/kuler/API/rss/}themeEditedAt";
        const string elname_swatch = "{http://kuler.adobe.com/kuler/API/rss/}swatch";

    }
}