﻿using SXL = System.Xml.Linq;

namespace Viziblr.Kuler
{
    public class ThemeListRequest
    {
        public ThemeListRequest(string apikey)
        {
            this.ListType = ThemeListType.Recent;
            this.APIKey = apikey;
        }

        public ThemeListType ListType { get; set; }
        public int? StartIndex { get; set; }
        public int? ItemsPerPage { get; set; }
        public int? TimeSpan { get; set; }
        public string APIKey { get; set; }

        public string GetURL()
        {
            string url = "http://kuler.adobe.com/kuler/API/rss/get.cfm?";
            string lt = null;
            switch (this.ListType)
            {
                case ThemeListType.HighestRated:
                    {
                        lt = "rating";
                        break;
                    }
                case ThemeListType.Popular:
                    {
                        lt = "popular";
                        break;
                    }
                case ThemeListType.Recent:
                    {
                        lt = "recent";
                        break;
                    }
                case ThemeListType.Random:
                    {
                        lt = "random";
                        break;
                    }
                default:
                    {
                        new KulerException("Unsupported List Type");
                        break;
                    }
            }

            url = url + "listtype=" + lt;

            if (this.StartIndex.HasValue)
            {
                url += "&startIndex=" + this.StartIndex.Value.ToString();
            }

            if (this.ItemsPerPage.HasValue)
            {
                url += "&itemsPerPage=" + this.ItemsPerPage.Value.ToString();
            }

            if (this.TimeSpan.HasValue)
            {
                url += "&timeSpan=" + this.TimeSpan.Value.ToString();
            }
            url += "&key=" + this.APIKey;
 
            return url;
        }

        public ThemesResult Execute()
        {
            var themeresult = new ThemesResult();
            themeresult.Themes.Clear();
            themeresult.URL = this.GetURL();

            var doc = SXL.XDocument.Load(themeresult.URL);

            var channel_el = doc.Root.Element("channel");
            if (channel_el == null)
            {
                throw new KulerException("Missing <channel> element");
            }

            themeresult.Title = channel_el.ElementValue("title");
            themeresult.Language = channel_el.ElementValue("language");
            themeresult.Link = channel_el.ElementValue("link");
            themeresult.Generator = channel_el.ElementValue("generator");
            themeresult.RecordCount = channel_el.ElementValueInt("recordCount");
            themeresult.StartIndex = channel_el.ElementValueInt("startIndex");

            foreach (var rss_item_el in channel_el.Elements("item"))
            {
                var theme_item_el = rss_item_el.Element(elname_themeitem);
                if (theme_item_el == null)
                {
                    throw new KulerException("missing <kuler:themeItem> element");
                }

                var theme_obj = Theme.FromXmlElement(theme_item_el);
                themeresult.Themes.Add(theme_obj);
            }

            return themeresult;
        }

        const string elname_themeitem = "{http://kuler.adobe.com/kuler/API/rss/}themeItem";
    }
}