using System.Diagnostics;
using System.Drawing;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Linq;
using System.Collections.Generic;
using VC = Colorspace;

namespace ViziblrTest
{
    [TestClass]
    public class TestColorRoundTrip
    {
        private static VC.RGBWorkingSpaces spaces = new VC.RGBWorkingSpaces();
        private static VC.RGBWorkingSpace SRGB_D65_2 = spaces.SRGB_D65_Degree2;
        [TestMethod]
        public void check_hsv_to_rgb()
        {
            var c1 = new VC.ColorHSV(1.0, 1.0, 1.0);
            var c2 = new VC.ColorRGB(c1);
        }

        [TestMethod]
        public void check_hsl_to_rgb()
        {
            var c1 = new VC.ColorHSL(1.0, 1.0, 1.0);
            var c2 = new VC.ColorRGB(c1);
        }

        public void round_trip_web_color_via_hsv(string webcolor)
        {
            var c0 = VC.ColorRGB32Bit.ParseWebColorString(webcolor);
            var c1 = System.Drawing.Color.FromArgb(c0.ToInt());
            var c2 = new VC.ColorRGB(c1.ToArgb());
            var c3 = new VC.ColorHSV( c2);
            var c4 = new VC.ColorRGB(c1.ToArgb());
            string out_webcolor = c0.ToWebColorString();
            Microsoft.VisualStudio.TestTools.UnitTesting.Assert.AreEqual(webcolor, out_webcolor);
        }

        public void round_trip_web_color_via_hsl(string webcolor)
        {
            var c0 = VC.ColorRGB32Bit.ParseWebColorString(webcolor);
            var c1 = System.Drawing.Color.FromArgb(c0.ToInt());
            var c2 = new VC.ColorRGB(c1.ToArgb());
            var c3 = new VC.ColorHSL(c2);
            var c4 = new VC.ColorRGB(c1.ToArgb());
            string out_webcolor = c0.ToWebColorString();
            Microsoft.VisualStudio.TestTools.UnitTesting.Assert.AreEqual(webcolor, out_webcolor);
        }

        [TestMethod]
        public void RoundTripWebColorViaHSV()
        {
            round_trip_web_color_via_hsv("#c0c0c0");
            round_trip_web_color_via_hsv("#0000ff");
            round_trip_web_color_via_hsv("#00ff00");
            round_trip_web_color_via_hsv("#ff0000");
            round_trip_web_color_via_hsv("#000000");
            round_trip_web_color_via_hsv("#ffffff");
            round_trip_web_color_via_hsv("#c0c0c0");
        }

        [TestMethod]
        public void RoundTripWebColorViaHSL()
        {
            round_trip_web_color_via_hsv("#c0c0c0");
            round_trip_web_color_via_hsl("#0000ff");
            round_trip_web_color_via_hsl("#00ff00");
            round_trip_web_color_via_hsl("#ff0000");
            round_trip_web_color_via_hsl("#000000");
            round_trip_web_color_via_hsl("#ffffff");
            round_trip_web_color_via_hsl("#c0c0c0");
        }

        [TestMethod]
        public void RoundTrip_Sytem_Drawing_Colors()
        {
            var records = GetColorRecords();

            foreach (var record in records)
            {
                var c0 = record.Color;
                check_roundtrip_rgb(c0);
                check_roundtrip_hsl(c0);
                check_roundtrip_hsv(c0);
                check_roundtrip_cmyk(c0);
                check_roundtrip_xyz(c0);
                check_roundtrip_lab(c0);
            }
        }

        private static List<ColorRecord> GetColorRecords()
        {
            var ct = typeof (System.Drawing.Color);
            var props = ct.GetProperties(System.Reflection.BindingFlags.Static | System.Reflection.BindingFlags.Public);
            var colorprops = props.Where(p => p.PropertyType == ct).ToArray();

            var col = new List<ColorRecord>();
            foreach (var p in colorprops)
            {
                var realcolor = (System.Drawing.Color) p.GetValue(null, null);
                var item = new ColorRecord(realcolor.Name, p.Name, realcolor);
                col.Add(item);
            }
            return col;
        }

        private static void check_roundtrip_rgb(Color c0)
        {
            var c1 = new VC.ColorRGB(c0.ToArgb());
            var c2 = new VC.ColorRGB32Bit(c1);
            var c3 = System.Drawing.Color.FromArgb(c2.ToInt());
            var c4 = new VC.ColorRGB32Bit(c3.ToArgb());
            var c5 = new VC.ColorRGB(c4);

            Assert.AreEqual(c0.R, c3.R);
            Assert.AreEqual(c0.G, c3.G);
            Assert.AreEqual(c0.B, c3.B);
            Assert.AreEqual(c0.A, c3.A);

            Assert.AreEqual(c2.R, c3.R);
            Assert.AreEqual(c2.G, c3.G);
            Assert.AreEqual(c2.B, c3.B);
            Assert.AreEqual(c2.Alpha, c3.A);

            Assert.AreEqual(c1.R, c5.R);
            Assert.AreEqual(c1.G, c5.G);
            Assert.AreEqual(c1.B, c5.B);
            Assert.AreEqual(c1.Alpha, c5.Alpha);
        }

        private static void check_roundtrip_hsl(Color c0)
        {
            var c1 = new VC.ColorRGB(c0.ToArgb());
            var c2 = new VC.ColorHSL(c1);
            var c3 = new VC.ColorRGB(c2);
            var c4 = new VC.ColorRGB32Bit(c3);
            var c5 = System.Drawing.Color.FromArgb(c4.ToInt());
            Assert.AreEqual(c0.R, c5.R, 1.0);
            Assert.AreEqual(c0.G, c5.G, 1.0);
            Assert.AreEqual(c0.B, c5.B, 1.0);
            Assert.AreEqual(c0.A, c5.A);
        }

        private static void check_roundtrip_hsv(Color c0)
        {
            var c1 = new VC.ColorRGB(c0.ToArgb());
            var c2 = new VC.ColorHSV(c1);
            var c3 = new VC.ColorRGB(c2);
            var c4 = new VC.ColorRGB32Bit(c3);
            var c5 = System.Drawing.Color.FromArgb(c4.ToInt());
            Assert.AreEqual(c0.R, c5.R, 1.0);
            Assert.AreEqual(c0.G, c5.G, 1.0);
            Assert.AreEqual(c0.B, c5.B, 1.0);
            Assert.AreEqual(c0.A, c5.A);
        }

        private static void check_roundtrip_cmyk(Color c0)
        {
            var c1 = new VC.ColorRGB(c0.ToArgb());
            var c2 = new VC.ColorCMYK(c1);
            var c3 = new VC.ColorRGB(c2);
            var c4 = new VC.ColorRGB32Bit(c3);
            var c5 = System.Drawing.Color.FromArgb(c4.ToInt());
            Assert.AreEqual(c0.R, c5.R, 1.0);
            Assert.AreEqual(c0.G, c5.G, 1.0);
            Assert.AreEqual(c0.B, c5.B, 1.0);
            Assert.AreEqual(c0.A, c5.A);
        }

        private static void check_roundtrip_xyz(Color c0)
        {
            var c1 = new VC.ColorRGB(c0.ToArgb());
            var c2 = new VC.ColorXYZ(c1, SRGB_D65_2);
            var c3 = new VC.ColorRGB(c2, SRGB_D65_2);
            var c4 = new VC.ColorRGB32Bit(c3);
            var c5 = System.Drawing.Color.FromArgb(c4.ToInt());
            Assert.AreEqual(c0.R, c5.R, 1.0);
            Assert.AreEqual(c0.G, c5.G, 1.0);
            Assert.AreEqual(c0.B, c5.B, 1.0);
            Assert.AreEqual(c0.A, c5.A);
        }

        private static void check_roundtrip_lab(Color c)
        {
            var c0 = new VC.ColorRGB(c.ToArgb());
            var c1 = new VC.ColorXYZ(c0, SRGB_D65_2);
            var c2 = new VC.ColorLAB(c1, SRGB_D65_2);
            var c3 = new VC.ColorRGB( new VC.ColorXYZ(c2,SRGB_D65_2), SRGB_D65_2);
            var c4 = new VC.ColorRGB32Bit(c3);
            var c5 = System.Drawing.Color.FromArgb(c4.ToInt());
            Assert.AreEqual(c.R, c5.R, 1.0);
            Assert.AreEqual(c.G, c5.G, 1.0);
            Assert.AreEqual(c.B, c5.B, 1.0);
            Assert.AreEqual(c.A, c5.A);
        }


        public IEnumerable<string> get_lines_from_string(string s)
        {
            
            var lines = s.SPLIT('\n');
            foreach (string line in lines)
            {
                string tline = line.Trim();
                if (tline.Length < 1)
                {
                    continue;
                }

                yield return line.Trim();
            }
        }

        [TestMethod]
        public void ValidateGray1()
        {
            var values = new double[] {0.0, 0.3, 0.5, 0.8, 1.0};
            foreach (var v in values)
            {
                var c0 = new VC.ColorRGB(v,v,v);
                var c1 = new VC.ColorHSL(c0);
                var c2 = new VC.ColorHSV(c0);
                Assert.IsTrue(double.IsNaN(c2.H));
                Assert.IsTrue(double.IsNaN(c1.H));
            }

        }

        [TestMethod]
        public void ValidateGray2()
        {
            var values = new double[] { 0.0, 0.3, 0.5, 0.8, 1.0 };
            foreach (var v in values)
            {
                var c0 = new VC.ColorHSV(double.NaN, double.NaN, v);
                var c1 = new VC.ColorHSL(double.NaN, double.NaN, v);

                var c0_rgb = new VC.ColorRGB(c0);
                Assert.IsTrue(c0_rgb.R == c0_rgb.G && c0_rgb.G == c0_rgb.B);

                var c1_rgb = new VC.ColorRGB(c1);
                Assert.IsTrue(c1_rgb.R == c1_rgb.G && c1_rgb.G == c1_rgb.B);

                Assert.IsFalse(c0.IsChromatic());
                Assert.IsFalse(c1.IsChromatic());
                Assert.IsFalse(c0_rgb.IsChromatic());
                Assert.IsFalse(c1_rgb.IsChromatic());
                //var c1 = new VC.ColorHSL(c0);
                //var c2 = new VC.ColorHSV(c0);
                //Assert.IsTrue(double.IsNaN(c2.H));
                //Assert.IsTrue(double.IsNaN(c1.H));
            }

        }




        [TestMethod]
        public void ValidateColorTranslation()
        {
            string pal_str = PalettesData.WikipediaColorList;
            foreach (string line in get_lines_from_string(pal_str))
            {
                var tokens = line.Replace("(","").Replace(")","").Replace("rgb=","").Replace("hsv=","").Replace("hsl=","").Split(new char[] { ',' });
                string name = tokens[0];
                string webcolor = tokens[1];
                var rgbint = VC.ColorRGB32Bit.ParseWebColorString(webcolor);
                var rgb = new VC.ColorRGB(rgbint);
                var hsv = new VC.ColorHSV(rgb);
                var hsl = new VC.ColorHSL(rgb);

                var doubles = tokens.Skip(2).Select(i => todouble(i)).ToArray();
                Assert.AreEqual(9,doubles.Length);

                var std_rgb = new VC.ColorRGB(doubles[0], doubles[1], doubles[2]);
                var std_hsl = new VC.ColorHSL(doubles[3], doubles[4], doubles[5]);
                var std_hsv = new VC.ColorHSV(doubles[6], doubles[7], doubles[8]);




                double delta = 0.000000000001;
                checkequal(std_rgb, rgb, delta);
                checkequal(std_hsv, hsv, delta);
                checkequal(std_hsl, hsl, delta);
            }
        }

        public double todouble(string s)
        {
            bool success;
            double d;
            success = double.TryParse(s, out d);
            if (success)
            {
                return d;
            }
            else
            {
                return double.NaN;
            }
        }

        public void nanequal(double a, double b, double delta)
        {
            if (double.IsNaN(a))
            {
                Assert.IsTrue(double.IsNaN(b));
            }
            else
            {
                Assert.IsFalse(double.IsNaN(b));
                Assert.AreEqual(a, b, delta);                
            }
        }

        public void checkequal(VC.ColorRGB a, VC.ColorRGB b, double delta)
        {
            nanequal(a.R, b.R, delta);
            nanequal(a.G, b.G, delta);
            nanequal(a.B, b.B, delta);            
        }

        public void checkequal(VC.ColorHSL a, VC.ColorHSL b, double delta)
        {
            nanequal(a.H,b.H, delta);
            nanequal(a.S,b.S, delta);
            nanequal(a.L,b.L, delta);
        }

        public void checkequal(VC.ColorHSV a, VC.ColorHSV b, double delta)
        {
            nanequal(a.H, b.H, delta);
            nanequal(a.S, b.S, delta);
            nanequal(a.V, b.V, delta);
        }


        public string striplast(string s)
        {
            if (s.Length < 1)
            {
                return s;
            }
            return s.Substring(0, s.Length - 1);
        }

        public int striplastint(string s)
        {
            return int.Parse(striplast(s));
        }

    }

    public static class Ext
    {
        public static string[] SPLIT(this string s, char c)
        {
            return s.Split(new char [] {c});
        }

        public static bool IsChromatic(this VC.ColorRGB c)
        {
            return !((c.R == c.G) && (c.G==c.B));
        }
    }

    public class ColorRecord
    {
        public string Name;
        public string ID;
        public System.Drawing.Color Color;

        public ColorRecord(string name, string id, System.Drawing.Color c)
        {
            this.Name = name;
            this.ID = id;
            this.Color = c;
        }
    }

    public static class PalettesData
    {

        public static string WikipediaColorList = @"
Alice blue,F0F8FF,rgb=(0.941176470588,0.972549019608,1.0),hsl=(0.577777777778,1.0,0.970588235294),hsv=(0.577777777778,0.0588235294118,1.0)
Alizarin crimson,E32636,rgb=(0.890196078431,0.149019607843,0.211764705882),hsl=(0.985890652557,0.771428571429,0.519607843137),hsv=(0.985890652557,0.832599118943,0.890196078431)
Almond,EFDECD,rgb=(0.937254901961,0.870588235294,0.803921568627),hsl=(0.0833333333333,0.515151515152,0.870588235294),hsv=(0.0833333333333,0.142259414226,0.937254901961)
Amaranth,E52B50,rgb=(0.898039215686,0.16862745098,0.313725490196),hsl=(0.966845878136,0.781512605042,0.533333333333),hsv=(0.966845878136,0.812227074236,0.898039215686)
Amber (SAE/ECE),FF7E00,rgb=(1.0,0.494117647059,0.0),hsl=(0.0823529411765,1.0,0.5),hsv=(0.0823529411765,1.0,1.0)
Amber,FFBF00,rgb=(1.0,0.749019607843,0.0),hsl=(0.124836601307,1.0,0.5),hsv=(0.124836601307,1.0,1.0)
American rose,FF033E,rgb=(1.0,0.0117647058824,0.243137254902),hsl=(0.960978835979,1.0,0.505882352941),hsv=(0.960978835979,0.988235294118,1.0)
Amethyst,9966CC,rgb=(0.6,0.4,0.8),hsl=(0.75,0.5,0.6),hsv=(0.75,0.5,0.8)
Android Green,A4C639,rgb=(0.643137254902,0.776470588235,0.223529411765),hsl=(0.206855791962,0.552941176471,0.5),hsv=(0.206855791962,0.712121212121,0.776470588235)
Anti-flash white,F2F3F4,rgb=(0.949019607843,0.952941176471,0.956862745098),hsl=(0.583333333333,0.0833333333333,0.952941176471),hsv=(0.583333333333,0.00819672131148,0.956862745098)
Antique brass,CD9575,rgb=(0.803921568627,0.58431372549,0.458823529412),hsl=(0.0606060606061,0.468085106383,0.63137254902),hsv=(0.0606060606061,0.429268292683,0.803921568627)
Antique fuchsia,915C83,rgb=(0.56862745098,0.360784313725,0.513725490196),hsl=(0.877358490566,0.223628691983,0.464705882353),hsv=(0.877358490566,0.365517241379,0.56862745098)
Antique white,FAEBD7,rgb=(0.980392156863,0.921568627451,0.843137254902),hsl=(0.0952380952381,0.777777777778,0.911764705882),hsv=(0.0952380952381,0.14,0.980392156863)
Ao (English),008000,rgb=(0.0,0.501960784314,0.0),hsl=(0.333333333333,1.0,0.250980392157),hsv=(0.333333333333,1.0,0.501960784314)
Apple green,8DB600,rgb=(0.552941176471,0.713725490196,0.0),hsl=(0.204212454212,1.0,0.356862745098),hsv=(0.204212454212,1.0,0.713725490196)
Apricot,FBCEB1,rgb=(0.98431372549,0.807843137255,0.694117647059),hsl=(0.0653153153153,0.90243902439,0.839215686275),hsv=(0.0653153153153,0.294820717131,0.98431372549)
Aqua,00FFFF,rgb=(0.0,1.0,1.0),hsl=(0.5,1.0,0.5),hsv=(0.5,1.0,1.0)
Aquamarine,7FFFD4,rgb=(0.498039215686,1.0,0.83137254902),hsl=(0.444010416667,1.0,0.749019607843),hsv=(0.444010416667,0.501960784314,1.0)
Army green,4B5320,rgb=(0.294117647059,0.325490196078,0.125490196078),hsl=(0.192810457516,0.44347826087,0.225490196078),hsv=(0.192810457516,0.614457831325,0.325490196078)
Arsenic,3B444B,rgb=(0.23137254902,0.266666666667,0.294117647059),hsl=(0.572916666667,0.119402985075,0.262745098039),hsv=(0.572916666667,0.213333333333,0.294117647059)
Arylide yellow,E9D66B,rgb=(0.913725490196,0.839215686275,0.419607843137),hsl=(0.141534391534,0.741176470588,0.666666666667),hsv=(0.141534391534,0.540772532189,0.913725490196)
Ash grey,B2BEB5,rgb=(0.698039215686,0.745098039216,0.709803921569),hsl=(0.375,0.0845070422535,0.721568627451),hsv=(0.375,0.0631578947368,0.745098039216)
Asparagus,87A96B,rgb=(0.529411764706,0.662745098039,0.419607843137),hsl=(0.258064516129,0.264957264957,0.541176470588),hsv=(0.258064516129,0.366863905325,0.662745098039)
Atomic tangerine,FF9966,rgb=(1.0,0.6,0.4),hsl=(0.0555555555556,1.0,0.7),hsv=(0.0555555555556,0.6,1.0)
Auburn,A52A2A,rgb=(0.647058823529,0.164705882353,0.164705882353),hsl=(0.0,0.594202898551,0.405882352941),hsv=(0.0,0.745454545455,0.647058823529)
Aureolin,FDEE00,rgb=(0.992156862745,0.933333333333,0.0),hsl=(0.156785243742,1.0,0.496078431373),hsv=(0.156785243742,1.0,0.992156862745)
Azure mist/web,F0FFFF,rgb=(0.941176470588,1.0,1.0),hsl=(0.5,1.0,0.970588235294),hsv=(0.5,0.0588235294118,1.0)
Azure,007FFF,rgb=(0.0,0.498039215686,1.0),hsl=(0.583660130719,1.0,0.5),hsv=(0.583660130719,1.0,1.0)
Baby blue eyes,A1CAF1,rgb=(0.63137254902,0.792156862745,0.945098039216),hsl=(0.58125,0.740740740741,0.788235294118),hsv=(0.58125,0.331950207469,0.945098039216)
Baby blue,89CFF0,rgb=(0.537254901961,0.811764705882,0.941176470588),hsl=(0.553398058252,0.774436090226,0.739215686275),hsv=(0.553398058252,0.429166666667,0.941176470588)
Banana yellow,FFE135,rgb=(1.0,0.882352941176,0.207843137255),hsl=(0.141914191419,1.0,0.603921568627),hsv=(0.141914191419,0.792156862745,1.0)
Battleship grey,848482,rgb=(0.517647058824,0.517647058824,0.509803921569),hsl=(0.166666666667,0.00806451612903,0.513725490196),hsv=(0.166666666667,0.0151515151515,0.517647058824)
Beau blue,BCD4E6,rgb=(0.737254901961,0.83137254902,0.901960784314),hsl=(0.571428571429,0.45652173913,0.819607843137),hsv=(0.571428571429,0.182608695652,0.901960784314)
Beige,F5F5DC,rgb=(0.960784313725,0.960784313725,0.862745098039),hsl=(0.166666666667,0.555555555556,0.911764705882),hsv=(0.166666666667,0.102040816327,0.960784313725)
Bisque,FFE4C4,rgb=(1.0,0.894117647059,0.76862745098),hsl=(0.090395480226,1.0,0.88431372549),hsv=(0.090395480226,0.23137254902,1.0)
Bistre,3D2B1F,rgb=(0.239215686275,0.16862745098,0.121568627451),hsl=(0.0666666666667,0.326086956522,0.180392156863),hsv=(0.0666666666667,0.491803278689,0.239215686275)
Bittersweet,FE6F5E,rgb=(0.996078431373,0.435294117647,0.36862745098),hsl=(0.0177083333333,0.987654320988,0.682352941176),hsv=(0.0177083333333,0.629921259843,0.996078431373)
Black,000000,rgb=(0.0,0.0,0.0),hsl=(-,-,0.0),hsv=(-,-,0.0)
Blanched Almond,FFEBCD,rgb=(1.0,0.921568627451,0.803921568627),hsl=(0.1,1.0,0.901960784314),hsv=(0.1,0.196078431373,1.0)
Blond,FAF0BE,rgb=(0.980392156863,0.941176470588,0.745098039216),hsl=(0.138888888889,0.857142857143,0.862745098039),hsv=(0.138888888889,0.24,0.980392156863)
Blue (Munsell),0093AF,rgb=(0.0,0.576470588235,0.686274509804),hsl=(0.526666666667,1.0,0.343137254902),hsv=(0.526666666667,1.0,0.686274509804)
Blue (NCS),0087BD,rgb=(0.0,0.529411764706,0.741176470588),hsl=(0.547619047619,1.0,0.370588235294),hsv=(0.547619047619,1.0,0.741176470588)
Blue (pigment),333399,rgb=(0.2,0.2,0.6),hsl=(0.666666666667,0.5,0.4),hsv=(0.666666666667,0.666666666667,0.6)
Blue (RYB),0247FE,rgb=(0.0078431372549,0.278431372549,0.996078431373),hsl=(0.621031746032,0.992125984252,0.501960784314),hsv=(0.621031746032,0.992125984252,0.996078431373)
Blue Bell,A2A2D0,rgb=(0.635294117647,0.635294117647,0.81568627451),hsl=(0.666666666667,0.328571428571,0.725490196078),hsv=(0.666666666667,0.221153846154,0.81568627451)
Blue Gray,6699CC,rgb=(0.4,0.6,0.8),hsl=(0.583333333333,0.5,0.6),hsv=(0.583333333333,0.5,0.8)
Blue,0000FF,rgb=(0.0,0.0,1.0),hsl=(0.666666666667,1.0,0.5),hsv=(0.666666666667,1.0,1.0)
Blue-green,00DDDD,rgb=(0.0,0.866666666667,0.866666666667),hsl=(0.5,1.0,0.433333333333),hsv=(0.5,1.0,0.866666666667)
Blue-violet,8A2BE2,rgb=(0.541176470588,0.16862745098,0.886274509804),hsl=(0.753187613843,0.759336099585,0.527450980392),hsv=(0.753187613843,0.809734513274,0.886274509804)
Blush,DE5D83,rgb=(0.870588235294,0.364705882353,0.513725490196),hsl=(0.950904392765,0.661538461538,0.617647058824),hsv=(0.950904392765,0.581081081081,0.870588235294)
Bondi blue,0095B6,rgb=(0.0,0.58431372549,0.713725490196),hsl=(0.53021978022,1.0,0.356862745098),hsv=(0.53021978022,1.0,0.713725490196)
Brass,B5A642,rgb=(0.709803921569,0.650980392157,0.258823529412),hsl=(0.144927536232,0.465587044534,0.48431372549),hsv=(0.144927536232,0.635359116022,0.709803921569)
Brick red,CB4154,rgb=(0.796078431373,0.254901960784,0.329411764706),hsl=(0.977053140097,0.570247933884,0.525490196078),hsv=(0.977053140097,0.679802955665,0.796078431373)
Bright green,66FF00,rgb=(0.4,1.0,0.0),hsl=(0.266666666667,1.0,0.5),hsv=(0.266666666667,1.0,1.0)
Bright lavender,BF94E4,rgb=(0.749019607843,0.580392156863,0.894117647059),hsl=(0.75625,0.597014925373,0.737254901961),hsv=(0.75625,0.350877192982,0.894117647059)
Bright maroon,C32148,rgb=(0.764705882353,0.129411764706,0.282352941176),hsl=(0.95987654321,0.710526315789,0.447058823529),hsv=(0.95987654321,0.830769230769,0.764705882353)
Bright pink,FF007F,rgb=(1.0,0.0,0.498039215686),hsl=(0.916993464052,1.0,0.5),hsv=(0.916993464052,1.0,1.0)
Bright turquoise,08E8DE,rgb=(0.0313725490196,0.909803921569,0.870588235294),hsl=(0.49255952381,0.933333333333,0.470588235294),hsv=(0.49255952381,0.965517241379,0.909803921569)
Brilliant lavender,F4BBFF,rgb=(0.956862745098,0.733333333333,1.0),hsl=(0.80637254902,1.0,0.866666666667),hsv=(0.80637254902,0.266666666667,1.0)
Brilliant rose,FF55A3,rgb=(1.0,0.333333333333,0.639215686275),hsl=(0.923529411765,1.0,0.666666666667),hsv=(0.923529411765,0.666666666667,1.0)
Brink pink,FB607F,rgb=(0.98431372549,0.376470588235,0.498039215686),hsl=(0.966666666667,0.950920245399,0.680392156863),hsv=(0.966666666667,0.617529880478,0.98431372549)
Bronze,CD7F32,rgb=(0.803921568627,0.498039215686,0.196078431373),hsl=(0.0827956989247,0.607843137255,0.5),hsv=(0.0827956989247,0.756097560976,0.803921568627)
Brown (traditional),964B00,rgb=(0.588235294118,0.294117647059,0.0),hsl=(0.0833333333333,1.0,0.294117647059),hsv=(0.0833333333333,1.0,0.588235294118)
Brown (web),A52A2A,rgb=(0.647058823529,0.164705882353,0.164705882353),hsl=(0.0,0.594202898551,0.405882352941),hsv=(0.0,0.745454545455,0.647058823529)
Bubble gum,FFC1CC,rgb=(1.0,0.756862745098,0.8),hsl=(0.970430107527,1.0,0.878431372549),hsv=(0.970430107527,0.243137254902,1.0)
Bubbles,E7FEFF,rgb=(0.905882352941,0.996078431373,1.0),hsl=(0.506944444444,1.0,0.952941176471),hsv=(0.506944444444,0.0941176470588,1.0)
Buff,F0DC82,rgb=(0.941176470588,0.862745098039,0.509803921569),hsl=(0.136363636364,0.785714285714,0.725490196078),hsv=(0.136363636364,0.458333333333,0.941176470588)
Burgundy,800020,rgb=(0.501960784314,0.0,0.125490196078),hsl=(0.958333333333,1.0,0.250980392157),hsv=(0.958333333333,1.0,0.501960784314)
Burlywood,DEB887,rgb=(0.870588235294,0.721568627451,0.529411764706),hsl=(0.0938697318008,0.56862745098,0.7),hsv=(0.0938697318008,0.391891891892,0.870588235294)
Burnt orange,CC5500,rgb=(0.8,0.333333333333,0.0),hsl=(0.0694444444444,1.0,0.4),hsv=(0.0694444444444,1.0,0.8)
Burnt sienna,E97451,rgb=(0.913725490196,0.454901960784,0.317647058824),hsl=(0.0383771929825,0.775510204082,0.61568627451),hsv=(0.0383771929825,0.652360515021,0.913725490196)
Burnt umber,8A3324,rgb=(0.541176470588,0.2,0.141176470588),hsl=(0.0245098039216,0.586206896552,0.341176470588),hsv=(0.0245098039216,0.739130434783,0.541176470588)
Byzantine,BD33A4,rgb=(0.741176470588,0.2,0.643137254902),hsl=(0.863526570048,0.575,0.470588235294),hsv=(0.863526570048,0.730158730159,0.741176470588)
Byzantium,702963,rgb=(0.439215686275,0.160784313725,0.388235294118),hsl=(0.863849765258,0.464052287582,0.3),hsv=(0.863849765258,0.633928571429,0.439215686275)
Cadet blue,5F9EA0,rgb=(0.372549019608,0.619607843137,0.627450980392),hsl=(0.505128205128,0.254901960784,0.5),hsv=(0.505128205128,0.40625,0.627450980392)
Cadet grey,91A3B0,rgb=(0.56862745098,0.639215686275,0.690196078431),hsl=(0.569892473118,0.164021164021,0.629411764706),hsv=(0.569892473118,0.176136363636,0.690196078431)
Cadet,536872,rgb=(0.325490196078,0.407843137255,0.447058823529),hsl=(0.55376344086,0.157360406091,0.386274509804),hsv=(0.55376344086,0.271929824561,0.447058823529)
Cadmium Green,006B3C,rgb=(0.0,0.419607843137,0.235294117647),hsl=(0.426791277259,1.0,0.209803921569),hsv=(0.426791277259,1.0,0.419607843137)
Cadmium Orange,ED872D,rgb=(0.929411764706,0.529411764706,0.176470588235),hsl=(0.078125,0.842105263158,0.552941176471),hsv=(0.078125,0.810126582278,0.929411764706)
Cadmium Red,E30022,rgb=(0.890196078431,0.0,0.133333333333),hsl=(0.97503671072,1.0,0.445098039216),hsv=(0.97503671072,1.0,0.890196078431)
Cadmium Yellow,FFF600,rgb=(1.0,0.964705882353,0.0),hsl=(0.160784313725,1.0,0.5),hsv=(0.160784313725,1.0,1.0)
Camel,C19A6B,rgb=(0.756862745098,0.603921568627,0.419607843137),hsl=(0.0910852713178,0.409523809524,0.588235294118),hsv=(0.0910852713178,0.445595854922,0.756862745098)
Camouflage green,78866B,rgb=(0.470588235294,0.525490196078,0.419607843137),hsl=(0.253086419753,0.112033195021,0.472549019608),hsv=(0.253086419753,0.201492537313,0.525490196078)
Canary yellow,FFEF00,rgb=(1.0,0.937254901961,0.0),hsl=(0.156209150327,1.0,0.5),hsv=(0.156209150327,1.0,1.0)
Candy apple red,FF0800,rgb=(1.0,0.0313725490196,0.0),hsl=(0.00522875816993,1.0,0.5),hsv=(0.00522875816993,1.0,1.0)
Candy pink,E4717A,rgb=(0.894117647059,0.443137254902,0.478431372549),hsl=(0.986956521739,0.680473372781,0.66862745098),hsv=(0.986956521739,0.504385964912,0.894117647059)
Capri,00BFFF,rgb=(0.0,0.749019607843,1.0),hsl=(0.541830065359,1.0,0.5),hsv=(0.541830065359,1.0,1.0)
Cardinal,C41E3A,rgb=(0.76862745098,0.117647058824,0.227450980392),hsl=(0.971887550201,0.734513274336,0.443137254902),hsv=(0.971887550201,0.84693877551,0.76862745098)
Caribbean green,00CC99,rgb=(0.0,0.8,0.6),hsl=(0.458333333333,1.0,0.4),hsv=(0.458333333333,1.0,0.8)
Carmine pink,EB4C42,rgb=(0.921568627451,0.298039215686,0.258823529412),hsl=(0.00986193293886,0.808612440191,0.590196078431),hsv=(0.00986193293886,0.71914893617,0.921568627451)
Carmine red,FF0038,rgb=(1.0,0.0,0.219607843137),hsl=(0.96339869281,1.0,0.5),hsv=(0.96339869281,1.0,1.0)
Carmine,960018,rgb=(0.588235294118,0.0,0.0941176470588),hsl=(0.973333333333,1.0,0.294117647059),hsv=(0.973333333333,1.0,0.588235294118)
Carnation pink,FFA6C9,rgb=(1.0,0.650980392157,0.788235294118),hsl=(0.934456928839,1.0,0.825490196078),hsv=(0.934456928839,0.349019607843,1.0)
Carnelian,B31B1B,rgb=(0.701960784314,0.105882352941,0.105882352941),hsl=(0.0,0.73786407767,0.403921568627),hsv=(0.0,0.849162011173,0.701960784314)
Carrot orange,ED9121,rgb=(0.929411764706,0.56862745098,0.129411764706),hsl=(0.0915032679739,0.85,0.529411764706),hsv=(0.0915032679739,0.860759493671,0.929411764706)
Ceil,92A1CF,rgb=(0.572549019608,0.63137254902,0.811764705882),hsl=(0.625683060109,0.388535031847,0.692156862745),hsv=(0.625683060109,0.294685990338,0.811764705882)
Celadon,ACE1AF,rgb=(0.674509803922,0.882352941176,0.686274509804),hsl=(0.342767295597,0.469026548673,0.778431372549),hsv=(0.342767295597,0.235555555556,0.882352941176)
Celestial blue,4997D0,rgb=(0.286274509804,0.592156862745,0.81568627451),hsl=(0.57037037037,0.589519650655,0.550980392157),hsv=(0.57037037037,0.649038461538,0.81568627451)
Cerise pink,EC3B83,rgb=(0.925490196078,0.23137254902,0.513725490196),hsl=(0.932203389831,0.823255813953,0.578431372549),hsv=(0.932203389831,0.75,0.925490196078)
Cerise,DE3163,rgb=(0.870588235294,0.192156862745,0.388235294118),hsl=(0.95183044316,0.723849372385,0.53137254902),hsv=(0.95183044316,0.779279279279,0.870588235294)
Cerulean blue,2A52BE,rgb=(0.164705882353,0.321568627451,0.745098039216),hsl=(0.621621621622,0.637931034483,0.454901960784),hsv=(0.621621621622,0.778947368421,0.745098039216)
Cerulean,007BA7,rgb=(0.0,0.482352941176,0.654901960784),hsl=(0.543912175649,1.0,0.327450980392),hsv=(0.543912175649,1.0,0.654901960784)
Chamoisee,A0785A,rgb=(0.627450980392,0.470588235294,0.352941176471),hsl=(0.0714285714286,0.28,0.490196078431),hsv=(0.0714285714286,0.4375,0.627450980392)
Champagne,F7E7CE,rgb=(0.96862745098,0.905882352941,0.807843137255),hsl=(0.10162601626,0.719298245614,0.888235294118),hsv=(0.10162601626,0.165991902834,0.96862745098)
Charcoal,36454F,rgb=(0.211764705882,0.270588235294,0.309803921569),hsl=(0.566666666667,0.187969924812,0.260784313725),hsv=(0.566666666667,0.316455696203,0.309803921569)
Chartreuse (traditional),DFFF00,rgb=(0.874509803922,1.0,0.0),hsl=(0.187581699346,1.0,0.5),hsv=(0.187581699346,1.0,1.0)
Chartreuse (web),7FFF00,rgb=(0.498039215686,1.0,0.0),hsl=(0.250326797386,1.0,0.5),hsv=(0.250326797386,1.0,1.0)
Cherry blossom pink,FFB7C5,rgb=(1.0,0.717647058824,0.772549019608),hsl=(0.967592592593,1.0,0.858823529412),hsv=(0.967592592593,0.282352941176,1.0)
Chestnut,CD5C5C,rgb=(0.803921568627,0.360784313725,0.360784313725),hsl=(0.0,0.530516431925,0.582352941176),hsv=(0.0,0.551219512195,0.803921568627)
Chocolate (traditional),7B3F00,rgb=(0.482352941176,0.247058823529,0.0),hsl=(0.0853658536585,1.0,0.241176470588),hsv=(0.0853658536585,1.0,0.482352941176)
Chocolate (web),D2691E,rgb=(0.823529411765,0.411764705882,0.117647058824),hsl=(0.0694444444444,0.75,0.470588235294),hsv=(0.0694444444444,0.857142857143,0.823529411765)
Chrome yellow,FFA700,rgb=(1.0,0.654901960784,0.0),hsl=(0.109150326797,1.0,0.5),hsv=(0.109150326797,1.0,1.0)
Cinereous,98817B,rgb=(0.596078431373,0.505882352941,0.482352941176),hsl=(0.0344827586207,0.123404255319,0.539215686275),hsv=(0.0344827586207,0.190789473684,0.596078431373)
Cinnabar,E34234,rgb=(0.890196078431,0.258823529412,0.203921568627),hsl=(0.0133333333333,0.757575757576,0.547058823529),hsv=(0.0133333333333,0.770925110132,0.890196078431)
Cinnamon,D2691E,rgb=(0.823529411765,0.411764705882,0.117647058824),hsl=(0.0694444444444,0.75,0.470588235294),hsv=(0.0694444444444,0.857142857143,0.823529411765)
Citrine,E4D00A,rgb=(0.894117647059,0.81568627451,0.0392156862745),hsl=(0.151376146789,0.915966386555,0.466666666667),hsv=(0.151376146789,0.956140350877,0.894117647059)
Classic rose,FBCCE7,rgb=(0.98431372549,0.8,0.905882352941),hsl=(0.904255319149,0.854545454545,0.892156862745),hsv=(0.904255319149,0.187250996016,0.98431372549)
Cobalt,0047AB,rgb=(0.0,0.278431372549,0.670588235294),hsl=(0.59746588694,1.0,0.335294117647),hsv=(0.59746588694,1.0,0.670588235294)
Cocoa brown,D2691E,rgb=(0.823529411765,0.411764705882,0.117647058824),hsl=(0.0694444444444,0.75,0.470588235294),hsv=(0.0694444444444,0.857142857143,0.823529411765)
Coffee,C86428,rgb=(0.78431372549,0.392156862745,0.156862745098),hsl=(0.0625,0.666666666667,0.470588235294),hsv=(0.0625,0.8,0.78431372549)
Cool black,002E63,rgb=(0.0,0.180392156863,0.388235294118),hsl=(0.589225589226,1.0,0.194117647059),hsv=(0.589225589226,1.0,0.388235294118)
Cool grey,8C92AC,rgb=(0.549019607843,0.572549019608,0.674509803922),hsl=(0.635416666667,0.161616161616,0.611764705882),hsv=(0.635416666667,0.186046511628,0.674509803922)
Copper rose,996666,rgb=(0.6,0.4,0.4),hsl=(0.0,0.2,0.5),hsv=(0.0,0.333333333333,0.6)
Copper,B87333,rgb=(0.721568627451,0.450980392157,0.2),hsl=(0.0802005012531,0.565957446809,0.460784313725),hsv=(0.0802005012531,0.722826086957,0.721568627451)
Coquelicot,FF3800,rgb=(1.0,0.219607843137,0.0),hsl=(0.0366013071895,1.0,0.5),hsv=(0.0366013071895,1.0,1.0)
Coral pink,F88379,rgb=(0.972549019608,0.513725490196,0.474509803922),hsl=(0.0131233595801,0.900709219858,0.723529411765),hsv=(0.0131233595801,0.512096774194,0.972549019608)
Coral red,FF4040,rgb=(1.0,0.250980392157,0.250980392157),hsl=(0.0,1.0,0.625490196078),hsv=(0.0,0.749019607843,1.0)
Coral,FF7F50,rgb=(1.0,0.498039215686,0.313725490196),hsl=(0.0447619047619,1.0,0.656862745098),hsv=(0.0447619047619,0.686274509804,1.0)
Cordovan,893F45,rgb=(0.537254901961,0.247058823529,0.270588235294),hsl=(0.986486486486,0.37,0.392156862745),hsv=(0.986486486486,0.540145985401,0.537254901961)
Corn,FBEC5D,rgb=(0.98431372549,0.925490196078,0.364705882353),hsl=(0.150843881857,0.951807228916,0.674509803922),hsv=(0.150843881857,0.629482071713,0.98431372549)
Cornflower blue,6495ED,rgb=(0.392156862745,0.58431372549,0.929411764706),hsl=(0.607055961071,0.791907514451,0.660784313725),hsv=(0.607055961071,0.57805907173,0.929411764706)
Cornsilk,FFF8DC,rgb=(1.0,0.972549019608,0.862745098039),hsl=(0.133333333333,1.0,0.93137254902),hsv=(0.133333333333,0.137254901961,1.0)
Cosmic latte,FFF8E7,rgb=(1.0,0.972549019608,0.905882352941),hsl=(0.118055555556,1.0,0.952941176471),hsv=(0.118055555556,0.0941176470588,1.0)
Cotton candy,FFBCD9,rgb=(1.0,0.737254901961,0.850980392157),hsl=(0.927860696517,1.0,0.86862745098),hsv=(0.927860696517,0.262745098039,1.0)
Cream,FFFDD0,rgb=(1.0,0.992156862745,0.81568627451),hsl=(0.159574468085,1.0,0.907843137255),hsv=(0.159574468085,0.18431372549,1.0)
Crimson glory,BE0032,rgb=(0.745098039216,0.0,0.196078431373),hsl=(0.956140350877,1.0,0.372549019608),hsv=(0.956140350877,1.0,0.745098039216)
Crimson,DC143C,rgb=(0.862745098039,0.078431372549,0.235294117647),hsl=(0.966666666667,0.833333333333,0.470588235294),hsv=(0.966666666667,0.909090909091,0.862745098039)
Cyan (process),00B7EB,rgb=(0.0,0.717647058824,0.921568627451),hsl=(0.536879432624,1.0,0.460784313725),hsv=(0.536879432624,1.0,0.921568627451)
Cyan,00FFFF,rgb=(0.0,1.0,1.0),hsl=(0.5,1.0,0.5),hsv=(0.5,1.0,1.0)
Daffodil,FFFF31,rgb=(1.0,1.0,0.192156862745),hsl=(0.166666666667,1.0,0.596078431373),hsv=(0.166666666667,0.807843137255,1.0)
Dandelion,F0E130,rgb=(0.941176470588,0.882352941176,0.188235294118),hsl=(0.153645833333,0.864864864865,0.564705882353),hsv=(0.153645833333,0.8,0.941176470588)
Dark blue,00008B,rgb=(0.0,0.0,0.545098039216),hsl=(0.666666666667,1.0,0.272549019608),hsv=(0.666666666667,1.0,0.545098039216)
Dark brown,654321,rgb=(0.396078431373,0.262745098039,0.129411764706),hsl=(0.0833333333333,0.507462686567,0.262745098039),hsv=(0.0833333333333,0.673267326733,0.396078431373)
Dark byzantium,5D3954,rgb=(0.364705882353,0.223529411765,0.329411764706),hsl=(0.875,0.24,0.294117647059),hsv=(0.875,0.387096774194,0.364705882353)
Dark candy apple red,A40000,rgb=(0.643137254902,0.0,0.0),hsl=(0.0,1.0,0.321568627451),hsv=(0.0,1.0,0.643137254902)
Dark cerulean,08457E,rgb=(0.0313725490196,0.270588235294,0.494117647059),hsl=(0.580508474576,0.880597014925,0.262745098039),hsv=(0.580508474576,0.936507936508,0.494117647059)
Dark champagne,C2B280,rgb=(0.760784313725,0.698039215686,0.501960784314),hsl=(0.126262626263,0.351063829787,0.63137254902),hsv=(0.126262626263,0.340206185567,0.760784313725)
Dark chestnut,986960,rgb=(0.596078431373,0.411764705882,0.376470588235),hsl=(0.0267857142857,0.225806451613,0.486274509804),hsv=(0.0267857142857,0.368421052632,0.596078431373)
Dark coral,CD5B45,rgb=(0.803921568627,0.356862745098,0.270588235294),hsl=(0.0269607843137,0.576271186441,0.537254901961),hsv=(0.0269607843137,0.663414634146,0.803921568627)
Dark cyan,008B8B,rgb=(0.0,0.545098039216,0.545098039216),hsl=(0.5,1.0,0.272549019608),hsv=(0.5,1.0,0.545098039216)
Dark electric blue,536878,rgb=(0.325490196078,0.407843137255,0.470588235294),hsl=(0.572072072072,0.182266009852,0.398039215686),hsv=(0.572072072072,0.308333333333,0.470588235294)
Dark goldenrod,B8860B,rgb=(0.721568627451,0.525490196078,0.043137254902),hsl=(0.118497109827,0.887179487179,0.382352941176),hsv=(0.118497109827,0.940217391304,0.721568627451)
Dark gray,A9A9A9,rgb=(0.662745098039,0.662745098039,0.662745098039),hsl=(-,-,0.662745098039),hsv=(-,-,0.662745098039)
Dark green,013220,rgb=(0.00392156862745,0.196078431373,0.125490196078),hsl=(0.438775510204,0.960784313725,0.1),hsv=(0.438775510204,0.98,0.196078431373)
Dark khaki,BDB76B,rgb=(0.741176470588,0.717647058824,0.419607843137),hsl=(0.154471544715,0.383177570093,0.580392156863),hsv=(0.154471544715,0.433862433862,0.741176470588)
Dark lava,483C32,rgb=(0.282352941176,0.235294117647,0.196078431373),hsl=(0.0757575757576,0.180327868852,0.239215686275),hsv=(0.0757575757576,0.305555555556,0.282352941176)
Dark lavender,734F96,rgb=(0.450980392157,0.309803921569,0.588235294118),hsl=(0.75117370892,0.310043668122,0.449019607843),hsv=(0.75117370892,0.473333333333,0.588235294118)
Dark magenta,8B008B,rgb=(0.545098039216,0.0,0.545098039216),hsl=(0.833333333333,1.0,0.272549019608),hsv=(0.833333333333,1.0,0.545098039216)
Dark midnight blue,003366,rgb=(0.0,0.2,0.4),hsl=(0.583333333333,1.0,0.2),hsv=(0.583333333333,1.0,0.4)
Dark olive green,556B2F,rgb=(0.333333333333,0.419607843137,0.18431372549),hsl=(0.227777777778,0.38961038961,0.301960784314),hsv=(0.227777777778,0.560747663551,0.419607843137)
Dark orange,FF8C00,rgb=(1.0,0.549019607843,0.0),hsl=(0.0915032679739,1.0,0.5),hsv=(0.0915032679739,1.0,1.0)
Dark orchid,9932CC,rgb=(0.6,0.196078431373,0.8),hsl=(0.778138528139,0.606299212598,0.498039215686),hsv=(0.778138528139,0.754901960784,0.8)
Dark pastel blue,779ECB,rgb=(0.466666666667,0.619607843137,0.796078431373),hsl=(0.589285714286,0.446808510638,0.63137254902),hsv=(0.589285714286,0.413793103448,0.796078431373)
Dark pastel green,03C03C,rgb=(0.0117647058824,0.752941176471,0.235294117647),hsl=(0.383597883598,0.969230769231,0.382352941176),hsv=(0.383597883598,0.984375,0.752941176471)
Dark pastel purple,966FD6,rgb=(0.588235294118,0.435294117647,0.839215686275),hsl=(0.729773462783,0.556756756757,0.637254901961),hsv=(0.729773462783,0.481308411215,0.839215686275)
Dark pastel red,C23B22,rgb=(0.760784313725,0.23137254902,0.133333333333),hsl=(0.0260416666667,0.701754385965,0.447058823529),hsv=(0.0260416666667,0.824742268041,0.760784313725)
Dark pink,E75480,rgb=(0.905882352941,0.329411764706,0.501960784314),hsl=(0.950113378685,0.753846153846,0.617647058824),hsv=(0.950113378685,0.636363636364,0.905882352941)
Dark powder blue,003399,rgb=(0.0,0.2,0.6),hsl=(0.611111111111,1.0,0.3),hsv=(0.611111111111,1.0,0.6)
Dark raspberry,872657,rgb=(0.529411764706,0.149019607843,0.341176470588),hsl=(0.915807560137,0.560693641618,0.339215686275),hsv=(0.915807560137,0.718518518519,0.529411764706)
Dark red,8B0000,rgb=(0.545098039216,0.0,0.0),hsl=(0.0,1.0,0.272549019608),hsv=(0.0,1.0,0.545098039216)
Dark salmon,E9967A,rgb=(0.913725490196,0.588235294118,0.478431372549),hsl=(0.042042042042,0.716129032258,0.696078431373),hsv=(0.042042042042,0.476394849785,0.913725490196)
Dark scarlet,560319,rgb=(0.337254901961,0.0117647058824,0.0980392156863),hsl=(0.955823293173,0.932584269663,0.174509803922),hsv=(0.955823293173,0.96511627907,0.337254901961)
Dark sea green,8FBC8F,rgb=(0.560784313725,0.737254901961,0.560784313725),hsl=(0.333333333333,0.251396648045,0.649019607843),hsv=(0.333333333333,0.239361702128,0.737254901961)
Dark sienna,3C1414,rgb=(0.235294117647,0.078431372549,0.078431372549),hsl=(0.0,0.5,0.156862745098),hsv=(0.0,0.666666666667,0.235294117647)
Dark slate blue,483D8B,rgb=(0.282352941176,0.239215686275,0.545098039216),hsl=(0.690170940171,0.39,0.392156862745),hsv=(0.690170940171,0.561151079137,0.545098039216)
Dark slate gray,2F4F4F,rgb=(0.18431372549,0.309803921569,0.309803921569),hsl=(0.5,0.253968253968,0.247058823529),hsv=(0.5,0.405063291139,0.309803921569)
Dark spring green,177245,rgb=(0.0901960784314,0.447058823529,0.270588235294),hsl=(0.417582417582,0.664233576642,0.26862745098),hsv=(0.417582417582,0.798245614035,0.447058823529)
Dark tan,918151,rgb=(0.56862745098,0.505882352941,0.317647058824),hsl=(0.125,0.283185840708,0.443137254902),hsv=(0.125,0.441379310345,0.56862745098)
Dark tangerine,FFA812,rgb=(1.0,0.658823529412,0.0705882352941),hsl=(0.105485232068,1.0,0.535294117647),hsv=(0.105485232068,0.929411764706,1.0)
Dark taupe,483C32,rgb=(0.282352941176,0.235294117647,0.196078431373),hsl=(0.0757575757576,0.180327868852,0.239215686275),hsv=(0.0757575757576,0.305555555556,0.282352941176)
Dark terra cotta,CC4E5C,rgb=(0.8,0.305882352941,0.360784313725),hsl=(0.981481481481,0.552631578947,0.552941176471),hsv=(0.981481481481,0.617647058824,0.8)
Dark turquoise,00CED1,rgb=(0.0,0.807843137255,0.819607843137),hsl=(0.502392344498,1.0,0.409803921569),hsv=(0.502392344498,1.0,0.819607843137)
Dark violet,9400D3,rgb=(0.580392156863,0.0,0.827450980392),hsl=(0.783570300158,1.0,0.413725490196),hsv=(0.783570300158,1.0,0.827450980392)
Deep carmine pink,EF3038,rgb=(0.937254901961,0.188235294118,0.219607843137),hsl=(0.993019197208,0.856502242152,0.562745098039),hsv=(0.993019197208,0.799163179916,0.937254901961)
Deep carmine,A9203E,rgb=(0.662745098039,0.125490196078,0.243137254902),hsl=(0.963503649635,0.681592039801,0.394117647059),hsv=(0.963503649635,0.810650887574,0.662745098039)
Deep carrot orange,E9692C,rgb=(0.913725490196,0.411764705882,0.172549019608),hsl=(0.0537918871252,0.811158798283,0.543137254902),hsv=(0.0537918871252,0.811158798283,0.913725490196)
Deep cerise,DA3287,rgb=(0.854901960784,0.196078431373,0.529411764706),hsl=(0.915674603175,0.694214876033,0.525490196078),hsv=(0.915674603175,0.770642201835,0.854901960784)
Deep champagne,FAD6A5,rgb=(0.980392156863,0.839215686275,0.647058823529),hsl=(0.0960784313725,0.894736842105,0.813725490196),hsv=(0.0960784313725,0.34,0.980392156863)
Deep chestnut,B94E48,rgb=(0.725490196078,0.305882352941,0.282352941176),hsl=(0.00884955752212,0.446640316206,0.503921568627),hsv=(0.00884955752212,0.610810810811,0.725490196078)
Deep fuchsia,C154C1,rgb=(0.756862745098,0.329411764706,0.756862745098),hsl=(0.833333333333,0.467811158798,0.543137254902),hsv=(0.833333333333,0.564766839378,0.756862745098)
Deep lilac,9955BB,rgb=(0.6,0.333333333333,0.733333333333),hsl=(0.777777777778,0.428571428571,0.533333333333),hsv=(0.777777777778,0.545454545455,0.733333333333)
Deep magenta,CC00CC,rgb=(0.8,0.0,0.8),hsl=(0.833333333333,1.0,0.4),hsv=(0.833333333333,1.0,0.8)
Deep peach,FFCBA4,rgb=(1.0,0.796078431373,0.643137254902),hsl=(0.0714285714286,1.0,0.821568627451),hsv=(0.0714285714286,0.356862745098,1.0)
Deep pink,FF1493,rgb=(1.0,0.078431372549,0.576470588235),hsl=(0.909929078014,1.0,0.539215686275),hsv=(0.909929078014,0.921568627451,1.0)
Deep saffron,FF9933,rgb=(1.0,0.6,0.2),hsl=(0.0833333333333,1.0,0.6),hsv=(0.0833333333333,0.8,1.0)
Deep sky blue,00BFFF,rgb=(0.0,0.749019607843,1.0),hsl=(0.541830065359,1.0,0.5),hsv=(0.541830065359,1.0,1.0)
Denim,1560BD,rgb=(0.0823529411765,0.376470588235,0.741176470588),hsl=(0.592261904762,0.8,0.411764705882),hsv=(0.592261904762,0.888888888889,0.741176470588)
Desert sand,EDC9AF,rgb=(0.929411764706,0.788235294118,0.686274509804),hsl=(0.0698924731183,0.632653061224,0.807843137255),hsv=(0.0698924731183,0.261603375527,0.929411764706)
Desert,C19A6B,rgb=(0.756862745098,0.603921568627,0.419607843137),hsl=(0.0910852713178,0.409523809524,0.588235294118),hsv=(0.0910852713178,0.445595854922,0.756862745098)
Dim gray,696969,rgb=(0.411764705882,0.411764705882,0.411764705882),hsl=(-,-,0.411764705882),hsv=(-,-,0.411764705882)
Dogwood rose,D71868,rgb=(0.843137254902,0.0941176470588,0.407843137255),hsl=(0.930191972077,0.799163179916,0.46862745098),hsv=(0.930191972077,0.888372093023,0.843137254902)
Drab,967117,rgb=(0.588235294118,0.443137254902,0.0901960784314),hsl=(0.11811023622,0.734104046243,0.339215686275),hsv=(0.11811023622,0.846666666667,0.588235294118)
Earth yellow,E1A95F,rgb=(0.882352941176,0.662745098039,0.372549019608),hsl=(0.0948717948718,0.684210526316,0.627450980392),hsv=(0.0948717948718,0.577777777778,0.882352941176)
Ecru,C2B280,rgb=(0.760784313725,0.698039215686,0.501960784314),hsl=(0.126262626263,0.351063829787,0.63137254902),hsv=(0.126262626263,0.340206185567,0.760784313725)
Eggplant,614051,rgb=(0.380392156863,0.250980392157,0.317647058824),hsl=(0.914141414141,0.204968944099,0.31568627451),hsv=(0.914141414141,0.340206185567,0.380392156863)
Eggshell,F0EAD6,rgb=(0.941176470588,0.917647058824,0.839215686275),hsl=(0.128205128205,0.464285714286,0.890196078431),hsv=(0.128205128205,0.108333333333,0.941176470588)
Electric blue,7DF9FF,rgb=(0.490196078431,0.976470588235,1.0),hsl=(0.507692307692,1.0,0.745098039216),hsv=(0.507692307692,0.509803921569,1.0)
Electric crimson,FF003F,rgb=(1.0,0.0,0.247058823529),hsl=(0.958823529412,1.0,0.5),hsv=(0.958823529412,1.0,1.0)
Electric cyan,00FFFF,rgb=(0.0,1.0,1.0),hsl=(0.5,1.0,0.5),hsv=(0.5,1.0,1.0)
Electric green,00FF00,rgb=(0.0,1.0,0.0),hsl=(0.333333333333,1.0,0.5),hsv=(0.333333333333,1.0,1.0)
Electric indigo,6F00FF,rgb=(0.435294117647,0.0,1.0),hsl=(0.739215686275,1.0,0.5),hsv=(0.739215686275,1.0,1.0)
Electric lavender,F4BBFF,rgb=(0.956862745098,0.733333333333,1.0),hsl=(0.80637254902,1.0,0.866666666667),hsv=(0.80637254902,0.266666666667,1.0)
Electric lime,CCFF00,rgb=(0.8,1.0,0.0),hsl=(0.2,1.0,0.5),hsv=(0.2,1.0,1.0)
Electric purple,BF00FF,rgb=(0.749019607843,0.0,1.0),hsl=(0.791503267974,1.0,0.5),hsv=(0.791503267974,1.0,1.0)
Electric ultramarine,3F00FF,rgb=(0.247058823529,0.0,1.0),hsl=(0.707843137255,1.0,0.5),hsv=(0.707843137255,1.0,1.0)
Electric violet,8F00FF,rgb=(0.560784313725,0.0,1.0),hsl=(0.760130718954,1.0,0.5),hsv=(0.760130718954,1.0,1.0)
Electric yellow,FFFF00,rgb=(1.0,1.0,0.0),hsl=(0.166666666667,1.0,0.5),hsv=(0.166666666667,1.0,1.0)
Emerald,50C878,rgb=(0.313725490196,0.78431372549,0.470588235294),hsl=(0.388888888889,0.521739130435,0.549019607843),hsv=(0.388888888889,0.6,0.78431372549)
Fallow,C19A6B,rgb=(0.756862745098,0.603921568627,0.419607843137),hsl=(0.0910852713178,0.409523809524,0.588235294118),hsv=(0.0910852713178,0.445595854922,0.756862745098)
Falu red,801818,rgb=(0.501960784314,0.0941176470588,0.0941176470588),hsl=(0.0,0.684210526316,0.298039215686),hsv=(0.0,0.8125,0.501960784314)
Fandango,B53389,rgb=(0.709803921569,0.2,0.537254901961),hsl=(0.889743589744,0.560344827586,0.454901960784),hsv=(0.889743589744,0.718232044199,0.709803921569)
Fashion fuchsia,F400A1,rgb=(0.956862745098,0.0,0.63137254902),hsl=(0.890027322404,1.0,0.478431372549),hsv=(0.890027322404,1.0,0.956862745098)
Fawn,E5AA70,rgb=(0.898039215686,0.666666666667,0.439215686275),hsl=(0.0826210826211,0.692307692308,0.66862745098),hsv=(0.0826210826211,0.510917030568,0.898039215686)
Feldgrau,4D5D53,rgb=(0.301960784314,0.364705882353,0.325490196078),hsl=(0.395833333333,0.0941176470588,0.333333333333),hsv=(0.395833333333,0.172043010753,0.364705882353)
Fern green,4F7942,rgb=(0.309803921569,0.474509803922,0.258823529412),hsl=(0.293939393939,0.294117647059,0.366666666667),hsv=(0.293939393939,0.454545454545,0.474509803922)
Field drab,6C541E,rgb=(0.423529411765,0.329411764706,0.117647058824),hsl=(0.115384615385,0.565217391304,0.270588235294),hsv=(0.115384615385,0.722222222222,0.423529411765)
Firebrick,B22222,rgb=(0.698039215686,0.133333333333,0.133333333333),hsl=(0.0,0.679245283019,0.41568627451),hsv=(0.0,0.808988764045,0.698039215686)
Flame,E25822,rgb=(0.886274509804,0.345098039216,0.133333333333),hsl=(0.046875,0.768,0.509803921569),hsv=(0.046875,0.849557522124,0.886274509804)
Flamingo pink,FC8EAC,rgb=(0.988235294118,0.556862745098,0.674509803922),hsl=(0.954545454545,0.948275862069,0.772549019608),hsv=(0.954545454545,0.436507936508,0.988235294118)
Flavescent,F7E98E,rgb=(0.96862745098,0.913725490196,0.556862745098),hsl=(0.144444444444,0.867768595041,0.762745098039),hsv=(0.144444444444,0.425101214575,0.96862745098)
Flax,EEDC82,rgb=(0.933333333333,0.862745098039,0.509803921569),hsl=(0.138888888889,0.760563380282,0.721568627451),hsv=(0.138888888889,0.453781512605,0.933333333333)
Floral white,FFFAF0,rgb=(1.0,0.980392156863,0.941176470588),hsl=(0.111111111111,1.0,0.970588235294),hsv=(0.111111111111,0.0588235294118,1.0)
Fluorescent orange,FFBF00,rgb=(1.0,0.749019607843,0.0),hsl=(0.124836601307,1.0,0.5),hsv=(0.124836601307,1.0,1.0)
Fluorescent pink,FF1493,rgb=(1.0,0.078431372549,0.576470588235),hsl=(0.909929078014,1.0,0.539215686275),hsv=(0.909929078014,0.921568627451,1.0)
Fluorescent yellow,CCFF00,rgb=(0.8,1.0,0.0),hsl=(0.2,1.0,0.5),hsv=(0.2,1.0,1.0)
Folly,FF004F,rgb=(1.0,0.0,0.309803921569),hsl=(0.948366013072,1.0,0.5),hsv=(0.948366013072,1.0,1.0)
Forest green (traditional),014421,rgb=(0.00392156862745,0.266666666667,0.129411764706),hsl=(0.412935323383,0.971014492754,0.135294117647),hsv=(0.412935323383,0.985294117647,0.266666666667)
Forest green (web),228B22,rgb=(0.133333333333,0.545098039216,0.133333333333),hsl=(0.333333333333,0.606936416185,0.339215686275),hsv=(0.333333333333,0.755395683453,0.545098039216)
French beige,A67B5B,rgb=(0.650980392157,0.482352941176,0.356862745098),hsl=(0.0711111111111,0.296442687747,0.503921568627),hsv=(0.0711111111111,0.451807228916,0.650980392157)
French blue,0072BB,rgb=(0.0,0.447058823529,0.733333333333),hsl=(0.565062388592,1.0,0.366666666667),hsv=(0.565062388592,1.0,0.733333333333)
French lilac,86608E,rgb=(0.525490196078,0.376470588235,0.556862745098),hsl=(0.804347826087,0.193277310924,0.466666666667),hsv=(0.804347826087,0.323943661972,0.556862745098)
French rose,F64A8A,rgb=(0.964705882353,0.290196078431,0.541176470588),hsl=(0.937984496124,0.905263157895,0.627450980392),hsv=(0.937984496124,0.69918699187,0.964705882353)
Fuchsia pink,FF77FF,rgb=(1.0,0.466666666667,1.0),hsl=(0.833333333333,1.0,0.733333333333),hsv=(0.833333333333,0.533333333333,1.0)
Fuchsia,FF00FF,rgb=(1.0,0.0,1.0),hsl=(0.833333333333,1.0,0.5),hsv=(0.833333333333,1.0,1.0)
Fulvous,E48400,rgb=(0.894117647059,0.517647058824,0.0),hsl=(0.0964912280702,1.0,0.447058823529),hsv=(0.0964912280702,1.0,0.894117647059)
Gainsboro,DCDCDC,rgb=(0.862745098039,0.862745098039,0.862745098039),hsl=(-,-,0.862745098039),hsv=(-,-,0.862745098039)
Gamboge,E49B0F,rgb=(0.894117647059,0.607843137255,0.0588235294118),hsl=(0.109546165884,0.876543209877,0.476470588235),hsv=(0.109546165884,0.934210526316,0.894117647059)
Ginger,B06500,rgb=(0.690196078431,0.396078431373,0.0),hsl=(0.0956439393939,1.0,0.345098039216),hsv=(0.0956439393939,1.0,0.690196078431)
Glaucous,6082B6,rgb=(0.376470588235,0.509803921569,0.713725490196),hsl=(0.600775193798,0.370689655172,0.545098039216),hsv=(0.600775193798,0.472527472527,0.713725490196)
Gold (metallic),D4AF37,rgb=(0.83137254902,0.686274509804,0.21568627451),hsl=(0.127388535032,0.646090534979,0.523529411765),hsv=(0.127388535032,0.740566037736,0.83137254902)
Gold (web) (Golden),FFD700,rgb=(1.0,0.843137254902,0.0),hsl=(0.140522875817,1.0,0.5),hsv=(0.140522875817,1.0,1.0)
Golden brown,996515,rgb=(0.6,0.396078431373,0.0823529411765),hsl=(0.10101010101,0.758620689655,0.341176470588),hsv=(0.10101010101,0.862745098039,0.6)
Golden poppy,FCC200,rgb=(0.988235294118,0.760784313725,0.0),hsl=(0.128306878307,1.0,0.494117647059),hsv=(0.128306878307,1.0,0.988235294118)
Golden yellow,FFDF00,rgb=(1.0,0.874509803922,0.0),hsl=(0.145751633987,1.0,0.5),hsv=(0.145751633987,1.0,1.0)
Goldenrod,DAA520,rgb=(0.854901960784,0.647058823529,0.125490196078),hsl=(0.11917562724,0.744,0.490196078431),hsv=(0.11917562724,0.853211009174,0.854901960784)
Granny Smith Apple,A8E4A0,rgb=(0.658823529412,0.894117647059,0.627450980392),hsl=(0.313725490196,0.55737704918,0.760784313725),hsv=(0.313725490196,0.298245614035,0.894117647059)
Gray (HTML/CSS gray),7F7F7F,rgb=(0.498039215686,0.498039215686,0.498039215686),hsl=(-,-,0.498039215686),hsv=(-,-,0.498039215686)
Gray (X11 gray),BEBEBE,rgb=(0.745098039216,0.745098039216,0.745098039216),hsl=(-,-,0.745098039216),hsv=(-,-,0.745098039216)
Gray,808080,rgb=(0.501960784314,0.501960784314,0.501960784314),hsl=(-,-,0.501960784314),hsv=(-,-,0.501960784314)
Gray-asparagus,465945,rgb=(0.274509803922,0.349019607843,0.270588235294),hsl=(0.325,0.126582278481,0.309803921569),hsv=(0.325,0.224719101124,0.349019607843)
Green (color wheel) (X11 green),00FF00,rgb=(0.0,1.0,0.0),hsl=(0.333333333333,1.0,0.5),hsv=(0.333333333333,1.0,1.0)
Green (HTML/CSS green),008000,rgb=(0.0,0.501960784314,0.0),hsl=(0.333333333333,1.0,0.250980392157),hsv=(0.333333333333,1.0,0.501960784314)
Green (Munsell),00A877,rgb=(0.0,0.658823529412,0.466666666667),hsl=(0.451388888889,1.0,0.329411764706),hsv=(0.451388888889,1.0,0.658823529412)
Green (pigment),00A550,rgb=(0.0,0.647058823529,0.313725490196),hsl=(0.414141414141,1.0,0.323529411765),hsv=(0.414141414141,1.0,0.647058823529)
Green (RYB),66B032,rgb=(0.4,0.690196078431,0.196078431373),hsl=(0.26455026455,0.557522123894,0.443137254902),hsv=(0.26455026455,0.715909090909,0.690196078431)
Green-yellow,ADFF2F,rgb=(0.678431372549,1.0,0.18431372549),hsl=(0.232371794872,1.0,0.592156862745),hsv=(0.232371794872,0.81568627451,1.0)
Grullo,A99A86,rgb=(0.662745098039,0.603921568627,0.525490196078),hsl=(0.0952380952381,0.169082125604,0.594117647059),hsv=(0.0952380952381,0.207100591716,0.662745098039)
Guppie green,00FF7F,rgb=(0.0,1.0,0.498039215686),hsl=(0.416339869281,1.0,0.5),hsv=(0.416339869281,1.0,1.0)
Han blue,446CCF,rgb=(0.266666666667,0.423529411765,0.811764705882),hsl=(0.618705035971,0.591489361702,0.539215686275),hsv=(0.618705035971,0.671497584541,0.811764705882)
Han purple,5218FA,rgb=(0.321568627451,0.0941176470588,0.980392156863),hsl=(0.709439528024,0.957627118644,0.537254901961),hsv=(0.709439528024,0.904,0.980392156863)
Hansa yellow,E9D66B,rgb=(0.913725490196,0.839215686275,0.419607843137),hsl=(0.141534391534,0.741176470588,0.666666666667),hsv=(0.141534391534,0.540772532189,0.913725490196)
Harlequin,3FFF00,rgb=(0.247058823529,1.0,0.0),hsl=(0.292156862745,1.0,0.5),hsv=(0.292156862745,1.0,1.0)
Harvest Gold,DA9100,rgb=(0.854901960784,0.56862745098,0.0),hsl=(0.110856269113,1.0,0.427450980392),hsv=(0.110856269113,1.0,0.854901960784)
Heart Gold,808000,rgb=(0.501960784314,0.501960784314,0.0),hsl=(0.166666666667,1.0,0.250980392157),hsv=(0.166666666667,1.0,0.501960784314)
Heliotrope,DF73FF,rgb=(0.874509803922,0.450980392157,1.0),hsl=(0.795238095238,1.0,0.725490196078),hsv=(0.795238095238,0.549019607843,1.0)
Hollywood cerise,F400A1,rgb=(0.956862745098,0.0,0.63137254902),hsl=(0.890027322404,1.0,0.478431372549),hsv=(0.890027322404,1.0,0.956862745098)
Honeydew,F0FFF0,rgb=(0.941176470588,1.0,0.941176470588),hsl=(0.333333333333,1.0,0.970588235294),hsv=(0.333333333333,0.0588235294118,1.0)
Hooker's green,007000,rgb=(0.0,0.439215686275,0.0),hsl=(0.333333333333,1.0,0.219607843137),hsv=(0.333333333333,1.0,0.439215686275)
Hot magenta,FF1DCE,rgb=(1.0,0.113725490196,0.807843137255),hsl=(0.869469026549,1.0,0.556862745098),hsv=(0.869469026549,0.886274509804,1.0)
Hot pink,FF69B4,rgb=(1.0,0.411764705882,0.705882352941),hsl=(0.916666666667,1.0,0.705882352941),hsv=(0.916666666667,0.588235294118,1.0)
Hunter green,355E3B,rgb=(0.207843137255,0.36862745098,0.23137254902),hsl=(0.357723577236,0.278911564626,0.288235294118),hsv=(0.357723577236,0.436170212766,0.36862745098)
Iceberg,71A6D2,rgb=(0.443137254902,0.650980392157,0.823529411765),hsl=(0.57560137457,0.51871657754,0.633333333333),hsv=(0.57560137457,0.461904761905,0.823529411765)
Icterine,FCF75E,rgb=(0.988235294118,0.96862745098,0.36862745098),hsl=(0.161392405063,0.963414634146,0.678431372549),hsv=(0.161392405063,0.626984126984,0.988235294118)
Inchworm,B2EC5D,rgb=(0.698039215686,0.925490196078,0.364705882353),hsl=(0.234265734266,0.790055248619,0.645098039216),hsv=(0.234265734266,0.60593220339,0.925490196078)
Indigo (dye),00416A,rgb=(0.0,0.254901960784,0.41568627451),hsl=(0.564465408805,1.0,0.207843137255),hsv=(0.564465408805,1.0,0.41568627451)
Indigo (web),4B0082,rgb=(0.294117647059,0.0,0.509803921569),hsl=(0.762820512821,1.0,0.254901960784),hsv=(0.762820512821,1.0,0.509803921569)
International Klein Blue,002FA7,rgb=(0.0,0.18431372549,0.654901960784),hsl=(0.619760479042,1.0,0.327450980392),hsv=(0.619760479042,1.0,0.654901960784)
International orange,FF4F00,rgb=(1.0,0.309803921569,0.0),hsl=(0.0516339869281,1.0,0.5),hsv=(0.0516339869281,1.0,1.0)
Iris,5A4FCF,rgb=(0.352941176471,0.309803921569,0.811764705882),hsl=(0.680989583333,0.571428571429,0.560784313725),hsv=(0.680989583333,0.618357487923,0.811764705882)
Isabelline,F4F0EC,rgb=(0.956862745098,0.941176470588,0.925490196078),hsl=(0.0833333333333,0.266666666667,0.941176470588),hsv=(0.0833333333333,0.0327868852459,0.956862745098)
Ivory,FFFFF0,rgb=(1.0,1.0,0.941176470588),hsl=(0.166666666667,1.0,0.970588235294),hsv=(0.166666666667,0.0588235294118,1.0)
Jade,00A86B,rgb=(0.0,0.658823529412,0.419607843137),hsl=(0.439484126984,1.0,0.329411764706),hsv=(0.439484126984,1.0,0.658823529412)
Jasmine,F8DE7E,rgb=(0.972549019608,0.870588235294,0.494117647059),hsl=(0.131147540984,0.897058823529,0.733333333333),hsv=(0.131147540984,0.491935483871,0.972549019608)
Jasper,D73B3E,rgb=(0.843137254902,0.23137254902,0.243137254902),hsl=(0.996794871795,0.661016949153,0.537254901961),hsv=(0.996794871795,0.725581395349,0.843137254902)
Jonquil,FADA5E,rgb=(0.980392156863,0.854901960784,0.36862745098),hsl=(0.132478632479,0.939759036145,0.674509803922),hsv=(0.132478632479,0.624,0.980392156863)
June bud,BDDA57,rgb=(0.741176470588,0.854901960784,0.341176470588),hsl=(0.203562340967,0.639024390244,0.598039215686),hsv=(0.203562340967,0.600917431193,0.854901960784)
Jungle green,29AB87,rgb=(0.160784313725,0.670588235294,0.529411764706),hsl=(0.453846153846,0.61320754717,0.41568627451),hsv=(0.453846153846,0.760233918129,0.670588235294)
Kelly green,4CBB17,rgb=(0.298039215686,0.733333333333,0.0901960784314),hsl=(0.279471544715,0.780952380952,0.411764705882),hsv=(0.279471544715,0.877005347594,0.733333333333)
Khaki (HTML/CSS) (Khaki),C3B091,rgb=(0.764705882353,0.690196078431,0.56862745098),hsl=(0.103333333333,0.294117647059,0.666666666667),hsv=(0.103333333333,0.25641025641,0.764705882353)
Khaki (X11) (Light khaki),F0E68C,rgb=(0.941176470588,0.901960784314,0.549019607843),hsl=(0.15,0.769230769231,0.745098039216),hsv=(0.15,0.416666666667,0.941176470588)
Languid lavender,D6CADD,rgb=(0.839215686275,0.792156862745,0.866666666667),hsl=(0.771929824561,0.218390804598,0.829411764706),hsv=(0.771929824561,0.0859728506787,0.866666666667)
Lapis lazuli,26619C,rgb=(0.149019607843,0.380392156863,0.611764705882),hsl=(0.583333333333,0.60824742268,0.380392156863),hsv=(0.583333333333,0.75641025641,0.611764705882)
Laser Lemon,FEFE22,rgb=(0.996078431373,0.996078431373,0.133333333333),hsl=(0.166666666667,0.990990990991,0.564705882353),hsv=(0.166666666667,0.866141732283,0.996078431373)
Lava,CF1020,rgb=(0.811764705882,0.0627450980392,0.125490196078),hsl=(0.986038394415,0.856502242152,0.437254901961),hsv=(0.986038394415,0.92270531401,0.811764705882)
Lavender (floral),B57EDC,rgb=(0.709803921569,0.494117647059,0.862745098039),hsl=(0.764184397163,0.573170731707,0.678431372549),hsv=(0.764184397163,0.427272727273,0.862745098039)
Lavender (web),E6E6FA,rgb=(0.901960784314,0.901960784314,0.980392156863),hsl=(0.666666666667,0.666666666667,0.941176470588),hsv=(0.666666666667,0.08,0.980392156863)
Lavender blue,CCCCFF,rgb=(0.8,0.8,1.0),hsl=(0.666666666667,1.0,0.9),hsv=(0.666666666667,0.2,1.0)
Lavender blush,FFF0F5,rgb=(1.0,0.941176470588,0.960784313725),hsl=(0.944444444444,1.0,0.970588235294),hsv=(0.944444444444,0.0588235294118,1.0)
Lavender gray,C4C3D0,rgb=(0.76862745098,0.764705882353,0.81568627451),hsl=(0.679487179487,0.121495327103,0.790196078431),hsv=(0.679487179487,0.0625,0.81568627451)
Lavender indigo,9457EB,rgb=(0.580392156863,0.341176470588,0.921568627451),hsl=(0.73536036036,0.787234042553,0.63137254902),hsv=(0.73536036036,0.629787234043,0.921568627451)
Lavender magenta,EE82EE,rgb=(0.933333333333,0.509803921569,0.933333333333),hsl=(0.833333333333,0.760563380282,0.721568627451),hsv=(0.833333333333,0.453781512605,0.933333333333)
Lavender mist,E6E6FA,rgb=(0.901960784314,0.901960784314,0.980392156863),hsl=(0.666666666667,0.666666666667,0.941176470588),hsv=(0.666666666667,0.08,0.980392156863)
Lavender pink,FBAED2,rgb=(0.98431372549,0.682352941176,0.823529411765),hsl=(0.922077922078,0.905882352941,0.833333333333),hsv=(0.922077922078,0.306772908367,0.98431372549)
Lavender purple,967BB6,rgb=(0.588235294118,0.482352941176,0.713725490196),hsl=(0.742937853107,0.287804878049,0.598039215686),hsv=(0.742937853107,0.324175824176,0.713725490196)
Lavender rose,FBA0E3,rgb=(0.98431372549,0.627450980392,0.890196078431),hsl=(0.877289377289,0.919191919192,0.805882352941),hsv=(0.877289377289,0.362549800797,0.98431372549)
Lawn green,7CFC00,rgb=(0.486274509804,0.988235294118,0.0),hsl=(0.251322751323,1.0,0.494117647059),hsv=(0.251322751323,1.0,0.988235294118)
Lemon chiffon,FFFACD,rgb=(1.0,0.980392156863,0.803921568627),hsl=(0.15,1.0,0.901960784314),hsv=(0.15,0.196078431373,1.0)
Lemon,FFF700,rgb=(1.0,0.96862745098,0.0),hsl=(0.161437908497,1.0,0.5),hsv=(0.161437908497,1.0,1.0)
Light apricot,FDD5B1,rgb=(0.992156862745,0.835294117647,0.694117647059),hsl=(0.0789473684211,0.95,0.843137254902),hsv=(0.0789473684211,0.300395256917,0.992156862745)
Light blue,ADD8E6,rgb=(0.678431372549,0.847058823529,0.901960784314),hsl=(0.540935672515,0.532710280374,0.790196078431),hsv=(0.540935672515,0.247826086957,0.901960784314)
Light brown,B5651D,rgb=(0.709803921569,0.396078431373,0.113725490196),hsl=(0.0789473684211,0.72380952381,0.411764705882),hsv=(0.0789473684211,0.839779005525,0.709803921569)
Light carmine pink,E66771,rgb=(0.901960784314,0.403921568627,0.443137254902),hsl=(0.98687664042,0.717514124294,0.652941176471),hsv=(0.98687664042,0.552173913043,0.901960784314)
Light coral,F08080,rgb=(0.941176470588,0.501960784314,0.501960784314),hsl=(0.0,0.788732394366,0.721568627451),hsv=(0.0,0.466666666667,0.941176470588)
Light cornflower blue,93CCEA,rgb=(0.576470588235,0.8,0.917647058824),hsl=(0.557471264368,0.674418604651,0.747058823529),hsv=(0.557471264368,0.371794871795,0.917647058824)
Light Crimson,F56991,rgb=(0.960784313725,0.411764705882,0.56862745098),hsl=(0.952380952381,0.875,0.686274509804),hsv=(0.952380952381,0.571428571429,0.960784313725)
Light cyan,E0FFFF,rgb=(0.878431372549,1.0,1.0),hsl=(0.5,1.0,0.939215686275),hsv=(0.5,0.121568627451,1.0)
Light fuchsia pink,F984EF,rgb=(0.976470588235,0.517647058824,0.937254901961),hsl=(0.847578347578,0.906976744186,0.747058823529),hsv=(0.847578347578,0.469879518072,0.976470588235)
Light goldenrod yellow,FAFAD2,rgb=(0.980392156863,0.980392156863,0.823529411765),hsl=(0.166666666667,0.8,0.901960784314),hsv=(0.166666666667,0.16,0.980392156863)
Light gray,D3D3D3,rgb=(0.827450980392,0.827450980392,0.827450980392),hsl=(-,-,0.827450980392),hsv=(-,-,0.827450980392)
Light green,90EE90,rgb=(0.564705882353,0.933333333333,0.564705882353),hsl=(0.333333333333,0.734375,0.749019607843),hsv=(0.333333333333,0.394957983193,0.933333333333)
Light khaki,F0E68C,rgb=(0.941176470588,0.901960784314,0.549019607843),hsl=(0.15,0.769230769231,0.745098039216),hsv=(0.15,0.416666666667,0.941176470588)
Light mauve,DCD0FF,rgb=(0.862745098039,0.81568627451,1.0),hsl=(0.709219858156,1.0,0.907843137255),hsv=(0.709219858156,0.18431372549,1.0)
Light pastel purple,B19CD9,rgb=(0.694117647059,0.611764705882,0.850980392157),hsl=(0.724043715847,0.445255474453,0.73137254902),hsv=(0.724043715847,0.281105990783,0.850980392157)
Light pink,FFB6C1,rgb=(1.0,0.713725490196,0.756862745098),hsl=(0.974885844749,1.0,0.856862745098),hsv=(0.974885844749,0.286274509804,1.0)
Light salmon pink,FF9999,rgb=(1.0,0.6,0.6),hsl=(0.0,1.0,0.8),hsv=(0.0,0.4,1.0)
Light salmon,FFA07A,rgb=(1.0,0.627450980392,0.478431372549),hsl=(0.047619047619,1.0,0.739215686275),hsv=(0.047619047619,0.521568627451,1.0)
Light sea green,20B2AA,rgb=(0.125490196078,0.698039215686,0.666666666667),hsl=(0.490867579909,0.695238095238,0.411764705882),hsv=(0.490867579909,0.820224719101,0.698039215686)
Light sky blue,87CEEB,rgb=(0.529411764706,0.807843137255,0.921568627451),hsl=(0.548333333333,0.714285714286,0.725490196078),hsv=(0.548333333333,0.425531914894,0.921568627451)
Light slate gray,778899,rgb=(0.466666666667,0.533333333333,0.6),hsl=(0.583333333333,0.142857142857,0.533333333333),hsv=(0.583333333333,0.222222222222,0.6)
Light taupe,B38B6D,rgb=(0.701960784314,0.545098039216,0.427450980392),hsl=(0.0714285714286,0.315315315315,0.564705882353),hsv=(0.0714285714286,0.391061452514,0.701960784314)
Light Thulian pink,E68FAC,rgb=(0.901960784314,0.560784313725,0.674509803922),hsl=(0.944444444444,0.63503649635,0.73137254902),hsv=(0.944444444444,0.378260869565,0.901960784314)
Light yellow,FFFFED,rgb=(1.0,1.0,0.929411764706),hsl=(0.166666666667,1.0,0.964705882353),hsv=(0.166666666667,0.0705882352941,1.0)
Lilac,C8A2C8,rgb=(0.78431372549,0.635294117647,0.78431372549),hsl=(0.833333333333,0.256756756757,0.709803921569),hsv=(0.833333333333,0.19,0.78431372549)
Lime (color wheel),BFFF00,rgb=(0.749019607843,1.0,0.0),hsl=(0.208496732026,1.0,0.5),hsv=(0.208496732026,1.0,1.0)
Lime (web) (X11 green),00FF00,rgb=(0.0,1.0,0.0),hsl=(0.333333333333,1.0,0.5),hsv=(0.333333333333,1.0,1.0)
Lime green,32CD32,rgb=(0.196078431373,0.803921568627,0.196078431373),hsl=(0.333333333333,0.607843137255,0.5),hsv=(0.333333333333,0.756097560976,0.803921568627)
Lincoln green,195905,rgb=(0.0980392156863,0.349019607843,0.0196078431373),hsl=(0.293650793651,0.893617021277,0.18431372549),hsv=(0.293650793651,0.943820224719,0.349019607843)
Linen,FAF0E6,rgb=(0.980392156863,0.941176470588,0.901960784314),hsl=(0.0833333333333,0.666666666667,0.941176470588),hsv=(0.0833333333333,0.08,0.980392156863)
Liver,534B4F,rgb=(0.325490196078,0.294117647059,0.309803921569),hsl=(0.916666666667,0.0506329113924,0.309803921569),hsv=(0.916666666667,0.0963855421687,0.325490196078)
Magenta (dye),CA1F7B,rgb=(0.792156862745,0.121568627451,0.482352941176),hsl=(0.910331384016,0.733905579399,0.456862745098),hsv=(0.910331384016,0.846534653465,0.792156862745)
Magenta (process),FF0090,rgb=(1.0,0.0,0.564705882353),hsl=(0.905882352941,1.0,0.5),hsv=(0.905882352941,1.0,1.0)
Magenta,FF00FF,rgb=(1.0,0.0,1.0),hsl=(0.833333333333,1.0,0.5),hsv=(0.833333333333,1.0,1.0)
Magic mint,AAF0D1,rgb=(0.666666666667,0.941176470588,0.819607843137),hsl=(0.42619047619,0.7,0.803921568627),hsv=(0.42619047619,0.291666666667,0.941176470588)
Magnolia,F8F4FF,rgb=(0.972549019608,0.956862745098,1.0),hsl=(0.727272727273,1.0,0.978431372549),hsv=(0.727272727273,0.043137254902,1.0)
Mahogany,C04000,rgb=(0.752941176471,0.250980392157,0.0),hsl=(0.0555555555556,1.0,0.376470588235),hsv=(0.0555555555556,1.0,0.752941176471)
Maize,FBEC5D,rgb=(0.98431372549,0.925490196078,0.364705882353),hsl=(0.150843881857,0.951807228916,0.674509803922),hsv=(0.150843881857,0.629482071713,0.98431372549)
Majorelle Blue,6050DC,rgb=(0.376470588235,0.313725490196,0.862745098039),hsl=(0.685714285714,0.666666666667,0.588235294118),hsv=(0.685714285714,0.636363636364,0.862745098039)
Malachite,0BDA51,rgb=(0.043137254902,0.854901960784,0.317647058824),hsl=(0.389694041868,0.903930131004,0.449019607843),hsv=(0.389694041868,0.949541284404,0.854901960784)
Mango Tango,FF8243,rgb=(1.0,0.509803921569,0.262745098039),hsl=(0.0558510638298,1.0,0.63137254902),hsv=(0.0558510638298,0.737254901961,1.0)
Maroon (HTML/CSS),800000,rgb=(0.501960784314,0.0,0.0),hsl=(0.0,1.0,0.250980392157),hsv=(0.0,1.0,0.501960784314)
Maroon (X11),B03060,rgb=(0.690196078431,0.188235294118,0.376470588235),hsl=(0.9375,0.571428571429,0.439215686275),hsv=(0.9375,0.727272727273,0.690196078431)
Mauve,E0B0FF,rgb=(0.878431372549,0.690196078431,1.0),hsl=(0.767932489451,1.0,0.845098039216),hsv=(0.767932489451,0.309803921569,1.0)
Mauvelous,EF98AA,rgb=(0.937254901961,0.596078431373,0.666666666667),hsl=(0.965517241379,0.731092436975,0.766666666667),hsv=(0.965517241379,0.364016736402,0.937254901961)
Maya blue,73C2FB,rgb=(0.450980392157,0.760784313725,0.98431372549),hsl=(0.569852941176,0.944444444444,0.717647058824),hsv=(0.569852941176,0.541832669323,0.98431372549)
Meat brown,E5B73B,rgb=(0.898039215686,0.717647058824,0.23137254902),hsl=(0.121568627451,0.765765765766,0.564705882353),hsv=(0.121568627451,0.742358078603,0.898039215686)
Medium aquamarine,66DDAA,rgb=(0.4,0.866666666667,0.666666666667),hsl=(0.428571428571,0.636363636364,0.633333333333),hsv=(0.428571428571,0.538461538462,0.866666666667)
Medium blue,0000CD,rgb=(0.0,0.0,0.803921568627),hsl=(0.666666666667,1.0,0.401960784314),hsv=(0.666666666667,1.0,0.803921568627)
Medium candy apple red,E2062C,rgb=(0.886274509804,0.0235294117647,0.172549019608),hsl=(0.971212121212,0.948275862069,0.454901960784),hsv=(0.971212121212,0.973451327434,0.886274509804)
Medium carmine,AF4035,rgb=(0.686274509804,0.250980392157,0.207843137255),hsl=(0.0150273224044,0.535087719298,0.447058823529),hsv=(0.0150273224044,0.697142857143,0.686274509804)
Medium champagne,F3E5AB,rgb=(0.952941176471,0.898039215686,0.670588235294),hsl=(0.134259259259,0.75,0.811764705882),hsv=(0.134259259259,0.296296296296,0.952941176471)
Medium electric blue,035096,rgb=(0.0117647058824,0.313725490196,0.588235294118),hsl=(0.579365079365,0.960784313725,0.3),hsv=(0.579365079365,0.98,0.588235294118)
Medium lavender magenta,DDA0DD,rgb=(0.866666666667,0.627450980392,0.866666666667),hsl=(0.833333333333,0.472868217054,0.747058823529),hsv=(0.833333333333,0.276018099548,0.866666666667)
Medium orchid,BA55D3,rgb=(0.729411764706,0.333333333333,0.827450980392),hsl=(0.800264550265,0.588785046729,0.580392156863),hsv=(0.800264550265,0.597156398104,0.827450980392)
Medium purple,9370DB,rgb=(0.576470588235,0.439215686275,0.858823529412),hsl=(0.721183800623,0.597765363128,0.649019607843),hsv=(0.721183800623,0.488584474886,0.858823529412)
Medium red-violet,BB3385,rgb=(0.733333333333,0.2,0.521568627451),hsl=(0.899509803922,0.571428571429,0.466666666667),hsv=(0.899509803922,0.727272727273,0.733333333333)
Medium sea green,3CB371,rgb=(0.235294117647,0.701960784314,0.443137254902),hsl=(0.40756302521,0.497907949791,0.46862745098),hsv=(0.40756302521,0.664804469274,0.701960784314)
Medium slate blue,7B68EE,rgb=(0.482352941176,0.407843137255,0.933333333333),hsl=(0.690298507463,0.797619047619,0.670588235294),hsv=(0.690298507463,0.563025210084,0.933333333333)
Medium spring bud,C9DC87,rgb=(0.788235294118,0.862745098039,0.529411764706),hsl=(0.203921568627,0.548387096774,0.696078431373),hsv=(0.203921568627,0.386363636364,0.862745098039)
Medium spring green,00FA9A,rgb=(0.0,0.980392156863,0.603921568627),hsl=(0.436,1.0,0.490196078431),hsv=(0.436,1.0,0.980392156863)
Medium taupe,674C47,rgb=(0.403921568627,0.298039215686,0.278431372549),hsl=(0.0260416666667,0.183908045977,0.341176470588),hsv=(0.0260416666667,0.31067961165,0.403921568627)
Medium teal blue,0054B4,rgb=(0.0,0.329411764706,0.705882352941),hsl=(0.588888888889,1.0,0.352941176471),hsv=(0.588888888889,1.0,0.705882352941)
Medium turquoise,48D1CC,rgb=(0.282352941176,0.819607843137,0.8),hsl=(0.493917274939,0.598253275109,0.550980392157),hsv=(0.493917274939,0.655502392344,0.819607843137)
Medium violet-red,C71585,rgb=(0.780392156863,0.0823529411765,0.521568627451),hsl=(0.895131086142,0.809090909091,0.43137254902),hsv=(0.895131086142,0.894472361809,0.780392156863)
Melon,FDBCB4,rgb=(0.992156862745,0.737254901961,0.705882352941),hsl=(0.0182648401826,0.948051948052,0.849019607843),hsv=(0.0182648401826,0.288537549407,0.992156862745)
Midnight blue,191970,rgb=(0.0980392156863,0.0980392156863,0.439215686275),hsl=(0.666666666667,0.63503649635,0.26862745098),hsv=(0.666666666667,0.776785714286,0.439215686275)
Midnight green (eagle green),004953,rgb=(0.0,0.286274509804,0.325490196078),hsl=(0.520080321285,1.0,0.162745098039),hsv=(0.520080321285,1.0,0.325490196078)
Mikado yellow,FFC40C,rgb=(1.0,0.76862745098,0.0470588235294),hsl=(0.126200274348,1.0,0.523529411765),hsv=(0.126200274348,0.952941176471,1.0)
Mint cream,F5FFFA,rgb=(0.960784313725,1.0,0.980392156863),hsl=(0.416666666667,1.0,0.980392156863),hsv=(0.416666666667,0.0392156862745,1.0)
Mint green,98FF98,rgb=(0.596078431373,1.0,0.596078431373),hsl=(0.333333333333,1.0,0.798039215686),hsv=(0.333333333333,0.403921568627,1.0)
Mint,3EB489,rgb=(0.243137254902,0.705882352941,0.537254901961),hsl=(0.439265536723,0.487603305785,0.474509803922),hsv=(0.439265536723,0.655555555556,0.705882352941)
Moccasin,FAEBD7,rgb=(0.980392156863,0.921568627451,0.843137254902),hsl=(0.0952380952381,0.777777777778,0.911764705882),hsv=(0.0952380952381,0.14,0.980392156863)
Mode beige,967117,rgb=(0.588235294118,0.443137254902,0.0901960784314),hsl=(0.11811023622,0.734104046243,0.339215686275),hsv=(0.11811023622,0.846666666667,0.588235294118)
Moonstone blue,73A9C2,rgb=(0.450980392157,0.662745098039,0.760784313725),hsl=(0.552742616034,0.393034825871,0.605882352941),hsv=(0.552742616034,0.407216494845,0.760784313725)
Mordant red 19,AE0C00,rgb=(0.682352941176,0.0470588235294,0.0),hsl=(0.0114942528736,1.0,0.341176470588),hsv=(0.0114942528736,1.0,0.682352941176)
Moss green,ADDFAD,rgb=(0.678431372549,0.874509803922,0.678431372549),hsl=(0.333333333333,0.438596491228,0.776470588235),hsv=(0.333333333333,0.224215246637,0.874509803922)
Mountain Meadow,30BA8F,rgb=(0.188235294118,0.729411764706,0.560784313725),hsl=(0.44806763285,0.589743589744,0.458823529412),hsv=(0.44806763285,0.741935483871,0.729411764706)
Mustard,FFDB58,rgb=(1.0,0.858823529412,0.345098039216),hsl=(0.130738522954,1.0,0.672549019608),hsv=(0.130738522954,0.654901960784,1.0)
Myrtle,21421E,rgb=(0.129411764706,0.258823529412,0.117647058824),hsl=(0.319444444444,0.375,0.188235294118),hsv=(0.319444444444,0.545454545455,0.258823529412)
Nadeshiko pink,F6ADC6,rgb=(0.964705882353,0.678431372549,0.776470588235),hsl=(0.942922374429,0.802197802198,0.821568627451),hsv=(0.942922374429,0.29674796748,0.964705882353)
Napier green,2A8000,rgb=(0.164705882353,0.501960784314,0.0),hsl=(0.278645833333,1.0,0.250980392157),hsv=(0.278645833333,1.0,0.501960784314)
Naples yellow,FADA5E,rgb=(0.980392156863,0.854901960784,0.36862745098),hsl=(0.132478632479,0.939759036145,0.674509803922),hsv=(0.132478632479,0.624,0.980392156863)
Navy blue,000080,rgb=(0.0,0.0,0.501960784314),hsl=(0.666666666667,1.0,0.250980392157),hsv=(0.666666666667,1.0,0.501960784314)
Neon Carrot,FFA343,rgb=(1.0,0.639215686275,0.262745098039),hsl=(0.0851063829787,1.0,0.63137254902),hsv=(0.0851063829787,0.737254901961,1.0)
Neon fuchsia,FE59C2,rgb=(0.996078431373,0.349019607843,0.760784313725),hsl=(0.893939393939,0.988023952096,0.672549019608),hsv=(0.893939393939,0.649606299213,0.996078431373)
Neon green,39FF14,rgb=(0.223529411765,1.0,0.078431372549),hsl=(0.307092198582,1.0,0.539215686275),hsv=(0.307092198582,0.921568627451,1.0)
Non-photo blue,A4DDED,rgb=(0.643137254902,0.866666666667,0.929411764706),hsl=(0.536529680365,0.669724770642,0.786274509804),hsv=(0.536529680365,0.308016877637,0.929411764706)
Ochre,CC7722,rgb=(0.8,0.466666666667,0.133333333333),hsl=(0.0833333333333,0.714285714286,0.466666666667),hsv=(0.0833333333333,0.833333333333,0.8)
Office green,008000,rgb=(0.0,0.501960784314,0.0),hsl=(0.333333333333,1.0,0.250980392157),hsv=(0.333333333333,1.0,0.501960784314)
Old gold,CFB53B,rgb=(0.811764705882,0.709803921569,0.23137254902),hsl=(0.137387387387,0.606557377049,0.521568627451),hsv=(0.137387387387,0.714975845411,0.811764705882)
Old lace,FDF5E6,rgb=(0.992156862745,0.960784313725,0.901960784314),hsl=(0.108695652174,0.851851851852,0.947058823529),hsv=(0.108695652174,0.0909090909091,0.992156862745)
Old lavender,796878,rgb=(0.474509803922,0.407843137255,0.470588235294),hsl=(0.843137254902,0.0755555555556,0.441176470588),hsv=(0.843137254902,0.140495867769,0.474509803922)
Old mauve,673147,rgb=(0.403921568627,0.192156862745,0.278431372549),hsl=(0.932098765432,0.355263157895,0.298039215686),hsv=(0.932098765432,0.52427184466,0.403921568627)
Old rose,C08081,rgb=(0.752941176471,0.501960784314,0.505882352941),hsl=(0.997395833333,0.336842105263,0.627450980392),hsv=(0.997395833333,0.333333333333,0.752941176471)
Olive Drab #7,3C341F,rgb=(0.235294117647,0.203921568627,0.121568627451),hsl=(0.120689655172,0.318681318681,0.178431372549),hsv=(0.120689655172,0.483333333333,0.235294117647)
Olive Drab (web) (Olive Drab #3),6B8E23,rgb=(0.419607843137,0.556862745098,0.137254901961),hsl=(0.221183800623,0.604519774011,0.347058823529),hsv=(0.221183800623,0.753521126761,0.556862745098)
Olive,808000,rgb=(0.501960784314,0.501960784314,0.0),hsl=(0.166666666667,1.0,0.250980392157),hsv=(0.166666666667,1.0,0.501960784314)
Olivine,9AB973,rgb=(0.603921568627,0.725490196078,0.450980392157),hsl=(0.240476190476,0.333333333333,0.588235294118),hsv=(0.240476190476,0.378378378378,0.725490196078)
Onyx,0F0F0F,rgb=(0.0588235294118,0.0588235294118,0.0588235294118),hsl=(-,-,0.0588235294118),hsv=(-,-,0.0588235294118)
Orange (color wheel),FF7F00,rgb=(1.0,0.498039215686,0.0),hsl=(0.0830065359477,1.0,0.5),hsv=(0.0830065359477,1.0,1.0)
Orange (RYB),FB9902,rgb=(0.98431372549,0.6,0.0078431372549),hsl=(0.101070950469,0.98418972332,0.496078431373),hsv=(0.101070950469,0.99203187251,0.98431372549)
Orange (web color),FFA500,rgb=(1.0,0.647058823529,0.0),hsl=(0.107843137255,1.0,0.5),hsv=(0.107843137255,1.0,1.0)
Orange peel,FF9F00,rgb=(1.0,0.623529411765,0.0),hsl=(0.103921568627,1.0,0.5),hsv=(0.103921568627,1.0,1.0)
Orange-red,FF4500,rgb=(1.0,0.270588235294,0.0),hsl=(0.0450980392157,1.0,0.5),hsv=(0.0450980392157,1.0,1.0)
Orchid,DA70D6,rgb=(0.854901960784,0.439215686275,0.839215686275),hsl=(0.839622641509,0.588888888889,0.647058823529),hsv=(0.839622641509,0.48623853211,0.854901960784)
Outrageous Orange,FF6E4A,rgb=(1.0,0.43137254902,0.290196078431),hsl=(0.0331491712707,1.0,0.645098039216),hsv=(0.0331491712707,0.709803921569,1.0)
Palatinate blue,273BE2,rgb=(0.152941176471,0.23137254902,0.886274509804),hsl=(0.648841354724,0.763265306122,0.519607843137),hsv=(0.648841354724,0.827433628319,0.886274509804)
Palatinate purple,682860,rgb=(0.407843137255,0.156862745098,0.376470588235),hsl=(0.854166666667,0.444444444444,0.282352941176),hsv=(0.854166666667,0.615384615385,0.407843137255)
Pale aqua,BCD4E6,rgb=(0.737254901961,0.83137254902,0.901960784314),hsl=(0.571428571429,0.45652173913,0.819607843137),hsv=(0.571428571429,0.182608695652,0.901960784314)
Pale blue,AFEEEE,rgb=(0.686274509804,0.933333333333,0.933333333333),hsl=(0.5,0.649484536082,0.809803921569),hsv=(0.5,0.264705882353,0.933333333333)
Pale brown,987654,rgb=(0.596078431373,0.462745098039,0.329411764706),hsl=(0.0833333333333,0.28813559322,0.462745098039),hsv=(0.0833333333333,0.447368421053,0.596078431373)
Pale carmine,AF4035,rgb=(0.686274509804,0.250980392157,0.207843137255),hsl=(0.0150273224044,0.535087719298,0.447058823529),hsv=(0.0150273224044,0.697142857143,0.686274509804)
Pale cerulean,9BC4E2,rgb=(0.607843137255,0.76862745098,0.886274509804),hsl=(0.570422535211,0.550387596899,0.747058823529),hsv=(0.570422535211,0.314159292035,0.886274509804)
Pale chestnut,DDADAF,rgb=(0.866666666667,0.678431372549,0.686274509804),hsl=(0.993055555556,0.413793103448,0.772549019608),hsv=(0.993055555556,0.217194570136,0.866666666667)
Pale copper,DA8A67,rgb=(0.854901960784,0.541176470588,0.403921568627),hsl=(0.0507246376812,0.608465608466,0.629411764706),hsv=(0.0507246376812,0.52752293578,0.854901960784)
Pale cornflower blue,ABCDEF,rgb=(0.670588235294,0.803921568627,0.937254901961),hsl=(0.583333333333,0.68,0.803921568627),hsv=(0.583333333333,0.284518828452,0.937254901961)
Pale gold,E6BE8A,rgb=(0.901960784314,0.745098039216,0.541176470588),hsl=(0.0942028985507,0.647887323944,0.721568627451),hsv=(0.0942028985507,0.4,0.901960784314)
Pale goldenrod,EEE8AA,rgb=(0.933333333333,0.909803921569,0.666666666667),hsl=(0.151960784314,0.666666666667,0.8),hsv=(0.151960784314,0.285714285714,0.933333333333)
Pale green,98FB98,rgb=(0.596078431373,0.98431372549,0.596078431373),hsl=(0.333333333333,0.92523364486,0.790196078431),hsv=(0.333333333333,0.394422310757,0.98431372549)
Pale magenta,F984E5,rgb=(0.976470588235,0.517647058824,0.898039215686),hsl=(0.861823361823,0.906976744186,0.747058823529),hsv=(0.861823361823,0.469879518072,0.976470588235)
Pale pink,FADADD,rgb=(0.980392156863,0.854901960784,0.866666666667),hsl=(0.984375,0.761904761905,0.917647058824),hsv=(0.984375,0.128,0.980392156863)
Pale plum,DDA0DD,rgb=(0.866666666667,0.627450980392,0.866666666667),hsl=(0.833333333333,0.472868217054,0.747058823529),hsv=(0.833333333333,0.276018099548,0.866666666667)
Pale red-violet,DB7093,rgb=(0.858823529412,0.439215686275,0.576470588235),hsl=(0.945482866044,0.597765363128,0.649019607843),hsv=(0.945482866044,0.488584474886,0.858823529412)
Pale robin egg blue,96DED1,rgb=(0.588235294118,0.870588235294,0.819607843137),hsl=(0.469907407407,0.521739130435,0.729411764706),hsv=(0.469907407407,0.324324324324,0.870588235294)
Pale silver,C9C0BB,rgb=(0.788235294118,0.752941176471,0.733333333333),hsl=(0.0595238095238,0.114754098361,0.760784313725),hsv=(0.0595238095238,0.0696517412935,0.788235294118)
Pale spring bud,ECEBBD,rgb=(0.925490196078,0.921568627451,0.741176470588),hsl=(0.163120567376,0.552941176471,0.833333333333),hsv=(0.163120567376,0.199152542373,0.925490196078)
Pale taupe,BC987E,rgb=(0.737254901961,0.596078431373,0.494117647059),hsl=(0.0698924731183,0.316326530612,0.61568627451),hsv=(0.0698924731183,0.329787234043,0.737254901961)
Pale violet-red,DB7093,rgb=(0.858823529412,0.439215686275,0.576470588235),hsl=(0.945482866044,0.597765363128,0.649019607843),hsv=(0.945482866044,0.488584474886,0.858823529412)
Papaya whip,FFEFD5,rgb=(1.0,0.937254901961,0.835294117647),hsl=(0.103174603175,1.0,0.917647058824),hsv=(0.103174603175,0.164705882353,1.0)
Paris Green,50C878,rgb=(0.313725490196,0.78431372549,0.470588235294),hsl=(0.388888888889,0.521739130435,0.549019607843),hsv=(0.388888888889,0.6,0.78431372549)
Pastel blue,AEC6CF,rgb=(0.682352941176,0.776470588235,0.811764705882),hsl=(0.545454545455,0.255813953488,0.747058823529),hsv=(0.545454545455,0.159420289855,0.811764705882)
Pastel brown,836953,rgb=(0.513725490196,0.411764705882,0.325490196078),hsl=(0.0763888888889,0.224299065421,0.419607843137),hsv=(0.0763888888889,0.36641221374,0.513725490196)
Pastel gray,CFCFC4,rgb=(0.811764705882,0.811764705882,0.76862745098),hsl=(0.166666666667,0.102803738318,0.790196078431),hsv=(0.166666666667,0.0531400966184,0.811764705882)
Pastel green,77DD77,rgb=(0.466666666667,0.866666666667,0.466666666667),hsl=(0.333333333333,0.6,0.666666666667),hsv=(0.333333333333,0.461538461538,0.866666666667)
Pastel magenta,F49AC2,rgb=(0.956862745098,0.603921568627,0.760784313725),hsl=(0.925925925926,0.803571428571,0.780392156863),hsv=(0.925925925926,0.368852459016,0.956862745098)
Pastel orange,FFB347,rgb=(1.0,0.701960784314,0.278431372549),hsl=(0.0978260869565,1.0,0.639215686275),hsv=(0.0978260869565,0.721568627451,1.0)
Pastel pink,FFD1DC,rgb=(1.0,0.819607843137,0.862745098039),hsl=(0.960144927536,1.0,0.909803921569),hsv=(0.960144927536,0.180392156863,1.0)
Pastel purple,B39EB5,rgb=(0.701960784314,0.619607843137,0.709803921569),hsl=(0.81884057971,0.134502923977,0.664705882353),hsv=(0.81884057971,0.127071823204,0.709803921569)
Pastel red,FF6961,rgb=(1.0,0.411764705882,0.380392156863),hsl=(0.0084388185654,1.0,0.690196078431),hsv=(0.0084388185654,0.619607843137,1.0)
Pastel violet,CB99C9,rgb=(0.796078431373,0.6,0.788235294118),hsl=(0.84,0.324675324675,0.698039215686),hsv=(0.84,0.246305418719,0.796078431373)
Pastel yellow,FDFD96,rgb=(0.992156862745,0.992156862745,0.588235294118),hsl=(0.166666666667,0.96261682243,0.790196078431),hsv=(0.166666666667,0.407114624506,0.992156862745)
Patriarch,800080,rgb=(0.501960784314,0.0,0.501960784314),hsl=(0.833333333333,1.0,0.250980392157),hsv=(0.833333333333,1.0,0.501960784314)
Payne's grey,40404F,rgb=(0.250980392157,0.250980392157,0.309803921569),hsl=(0.666666666667,0.104895104895,0.280392156863),hsv=(0.666666666667,0.189873417722,0.309803921569)
Peach puff,FFDAB9,rgb=(1.0,0.854901960784,0.725490196078),hsl=(0.0785714285714,1.0,0.862745098039),hsv=(0.0785714285714,0.274509803922,1.0)
Peach,FFE5B4,rgb=(1.0,0.898039215686,0.705882352941),hsl=(0.108888888889,1.0,0.852941176471),hsv=(0.108888888889,0.294117647059,1.0)
Peach-orange,FFCC99,rgb=(1.0,0.8,0.6),hsl=(0.0833333333333,1.0,0.8),hsv=(0.0833333333333,0.4,1.0)
Peach-yellow,FADFAD,rgb=(0.980392156863,0.874509803922,0.678431372549),hsl=(0.108225108225,0.885057471264,0.829411764706),hsv=(0.108225108225,0.308,0.980392156863)
Pear,D1E231,rgb=(0.819607843137,0.886274509804,0.192156862745),hsl=(0.182674199623,0.753191489362,0.539215686275),hsv=(0.182674199623,0.783185840708,0.886274509804)
Pearl Aqua,88D8C0,rgb=(0.533333333333,0.847058823529,0.752941176471),hsl=(0.45,0.506329113924,0.690196078431),hsv=(0.45,0.37037037037,0.847058823529)
Pearl,F0EAD6,rgb=(0.941176470588,0.917647058824,0.839215686275),hsl=(0.128205128205,0.464285714286,0.890196078431),hsv=(0.128205128205,0.108333333333,0.941176470588)
Peridot,E6E200,rgb=(0.901960784314,0.886274509804,0.0),hsl=(0.163768115942,1.0,0.450980392157),hsv=(0.163768115942,1.0,0.901960784314)
Periwinkle,CCCCFF,rgb=(0.8,0.8,1.0),hsl=(0.666666666667,1.0,0.9),hsv=(0.666666666667,0.2,1.0)
Persimmon,EC5800,rgb=(0.925490196078,0.345098039216,0.0),hsl=(0.0621468926554,1.0,0.462745098039),hsv=(0.0621468926554,1.0,0.925490196078)
Phlox,DF00FF,rgb=(0.874509803922,0.0,1.0),hsl=(0.812418300654,1.0,0.5),hsv=(0.812418300654,1.0,1.0)
Phthalo blue,000F89,rgb=(0.0,0.0588235294118,0.537254901961),hsl=(0.648418491484,1.0,0.26862745098),hsv=(0.648418491484,1.0,0.537254901961)
Phthalo green,123524,rgb=(0.0705882352941,0.207843137255,0.141176470588),hsl=(0.419047619048,0.492957746479,0.139215686275),hsv=(0.419047619048,0.660377358491,0.207843137255)
Piggy pink,FDDDE6,rgb=(0.992156862745,0.866666666667,0.901960784314),hsl=(0.953125,0.888888888889,0.929411764706),hsv=(0.953125,0.126482213439,0.992156862745)
Pine green,01796F,rgb=(0.00392156862745,0.474509803922,0.435294117647),hsl=(0.486111111111,0.983606557377,0.239215686275),hsv=(0.486111111111,0.99173553719,0.474509803922)
Pink pearl,E7ACCF,rgb=(0.905882352941,0.674509803922,0.811764705882),hsl=(0.901129943503,0.551401869159,0.790196078431),hsv=(0.901129943503,0.255411255411,0.905882352941)
Pink Sherbet,F78FA7,rgb=(0.96862745098,0.560784313725,0.654901960784),hsl=(0.961538461538,0.866666666667,0.764705882353),hsv=(0.961538461538,0.421052631579,0.96862745098)
Pink,FFC0CB,rgb=(1.0,0.752941176471,0.796078431373),hsl=(0.970899470899,1.0,0.876470588235),hsv=(0.970899470899,0.247058823529,1.0)
Pink-orange,FF9966,rgb=(1.0,0.6,0.4),hsl=(0.0555555555556,1.0,0.7),hsv=(0.0555555555556,0.6,1.0)
Pistachio,93C572,rgb=(0.576470588235,0.772549019608,0.447058823529),hsl=(0.267068273092,0.417085427136,0.609803921569),hsv=(0.267068273092,0.421319796954,0.772549019608)
Platinum,E5E4E2,rgb=(0.898039215686,0.894117647059,0.886274509804),hsl=(0.111111111111,0.0545454545455,0.892156862745),hsv=(0.111111111111,0.0131004366812,0.898039215686)
Plum (traditional),8E4585,rgb=(0.556862745098,0.270588235294,0.521568627451),hsl=(0.853881278539,0.345971563981,0.413725490196),hsv=(0.853881278539,0.514084507042,0.556862745098)
Plum (web),DDA0DD,rgb=(0.866666666667,0.627450980392,0.866666666667),hsl=(0.833333333333,0.472868217054,0.747058823529),hsv=(0.833333333333,0.276018099548,0.866666666667)
Powder blue (web),B0E0E6,rgb=(0.690196078431,0.878431372549,0.901960784314),hsl=(0.518518518519,0.519230769231,0.796078431373),hsv=(0.518518518519,0.234782608696,0.901960784314)
Prune,701C1C,rgb=(0.439215686275,0.109803921569,0.109803921569),hsl=(0.0,0.6,0.274509803922),hsv=(0.0,0.75,0.439215686275)
Prussian blue,003153,rgb=(0.0,0.192156862745,0.325490196078),hsl=(0.568273092369,1.0,0.162745098039),hsv=(0.568273092369,1.0,0.325490196078)
Puce,CC8899,rgb=(0.8,0.533333333333,0.6),hsl=(0.958333333333,0.4,0.666666666667),hsv=(0.958333333333,0.333333333333,0.8)
Pumpkin,FF7518,rgb=(1.0,0.458823529412,0.0941176470588),hsl=(0.0670995670996,1.0,0.547058823529),hsv=(0.0670995670996,0.905882352941,1.0)
Purple (HTML/CSS),800080,rgb=(0.501960784314,0.0,0.501960784314),hsl=(0.833333333333,1.0,0.250980392157),hsv=(0.833333333333,1.0,0.501960784314)
Purple (Munsell),9F00C5,rgb=(0.623529411765,0.0,0.772549019608),hsl=(0.801184433164,1.0,0.386274509804),hsv=(0.801184433164,1.0,0.772549019608)
Purple (X11),A020F0,rgb=(0.627450980392,0.125490196078,0.941176470588),hsl=(0.769230769231,0.873949579832,0.533333333333),hsv=(0.769230769231,0.866666666667,0.941176470588)
Purple Heart,69359C,rgb=(0.411764705882,0.207843137255,0.611764705882),hsl=(0.750809061489,0.492822966507,0.409803921569),hsv=(0.750809061489,0.660256410256,0.611764705882)
Purple mountain majesty,9678B6,rgb=(0.588235294118,0.470588235294,0.713725490196),hsl=(0.747311827957,0.298076923077,0.592156862745),hsv=(0.747311827957,0.340659340659,0.713725490196)
Purple taupe,50404D,rgb=(0.313725490196,0.250980392157,0.301960784314),hsl=(0.864583333333,0.111111111111,0.282352941176),hsv=(0.864583333333,0.2,0.313725490196)
Quartz,51484F,rgb=(0.317647058824,0.282352941176,0.309803921569),hsl=(0.87037037037,0.0588235294118,0.3),hsv=(0.87037037037,0.111111111111,0.317647058824)
Raspberry glace,915F6D,rgb=(0.56862745098,0.372549019608,0.427450980392),hsl=(0.953333333333,0.208333333333,0.470588235294),hsv=(0.953333333333,0.344827586207,0.56862745098)
Raspberry pink,E25098,rgb=(0.886274509804,0.313725490196,0.596078431373),hsl=(0.917808219178,0.71568627451,0.6),hsv=(0.917808219178,0.646017699115,0.886274509804)
Raspberry,E30B5D,rgb=(0.890196078431,0.043137254902,0.364705882353),hsl=(0.936728395062,0.90756302521,0.466666666667),hsv=(0.936728395062,0.95154185022,0.890196078431)
Raw umber,826644,rgb=(0.509803921569,0.4,0.266666666667),hsl=(0.0913978494624,0.313131313131,0.388235294118),hsv=(0.0913978494624,0.476923076923,0.509803921569)
Razzle dazzle rose,FF33CC,rgb=(1.0,0.2,0.8),hsl=(0.875,1.0,0.6),hsv=(0.875,0.8,1.0)
Razzmatazz,E3256B,rgb=(0.890196078431,0.145098039216,0.419607843137),hsl=(0.938596491228,0.772357723577,0.517647058824),hsv=(0.938596491228,0.837004405286,0.890196078431)
Red (Munsell),F2003C,rgb=(0.949019607843,0.0,0.235294117647),hsl=(0.95867768595,1.0,0.474509803922),hsv=(0.95867768595,1.0,0.949019607843)
Red (NCS),C40233,rgb=(0.76862745098,0.0078431372549,0.2),hsl=(0.957903780069,0.979797979798,0.388235294118),hsv=(0.957903780069,0.989795918367,0.76862745098)
Red (RYB),FE2712,rgb=(0.996078431373,0.152941176471,0.0705882352941),hsl=(0.0148305084746,0.991596638655,0.533333333333),hsv=(0.0148305084746,0.929133858268,0.996078431373)
Red,FF0000,rgb=(1.0,0.0,0.0),hsl=(0.0,1.0,0.5),hsv=(0.0,1.0,1.0)
Red-brown,A52A2A,rgb=(0.647058823529,0.164705882353,0.164705882353),hsl=(0.0,0.594202898551,0.405882352941),hsv=(0.0,0.745454545455,0.647058823529)
Red-violet,C71585,rgb=(0.780392156863,0.0823529411765,0.521568627451),hsl=(0.895131086142,0.809090909091,0.43137254902),hsv=(0.895131086142,0.894472361809,0.780392156863)
Redwood,AB4E52,rgb=(0.670588235294,0.305882352941,0.321568627451),hsl=(0.992831541219,0.373493975904,0.488235294118),hsv=(0.992831541219,0.543859649123,0.670588235294)
Rich black,004040,rgb=(0.0,0.250980392157,0.250980392157),hsl=(0.5,1.0,0.125490196078),hsv=(0.5,1.0,0.250980392157)
Rich brilliant lavender,F1A7FE,rgb=(0.945098039216,0.654901960784,0.996078431373),hsl=(0.808429118774,0.977528089888,0.825490196078),hsv=(0.808429118774,0.342519685039,0.996078431373)
Rich carmine,D70040,rgb=(0.843137254902,0.0,0.250980392157),hsl=(0.950387596899,1.0,0.421568627451),hsv=(0.950387596899,1.0,0.843137254902)
Rich electric blue,0892D0,rgb=(0.0313725490196,0.572549019608,0.81568627451),hsl=(0.551666666667,0.925925925926,0.423529411765),hsv=(0.551666666667,0.961538461538,0.81568627451)
Rich lavender,A76BCF,rgb=(0.654901960784,0.419607843137,0.811764705882),hsl=(0.766666666667,0.510204081633,0.61568627451),hsv=(0.766666666667,0.48309178744,0.811764705882)
Rich lilac,B666D2,rgb=(0.713725490196,0.4,0.823529411765),hsl=(0.79012345679,0.545454545455,0.611764705882),hsv=(0.79012345679,0.514285714286,0.823529411765)
Rich maroon,B03060,rgb=(0.690196078431,0.188235294118,0.376470588235),hsl=(0.9375,0.571428571429,0.439215686275),hsv=(0.9375,0.727272727273,0.690196078431)
Rifle green,414833,rgb=(0.254901960784,0.282352941176,0.2),hsl=(0.222222222222,0.170731707317,0.241176470588),hsv=(0.222222222222,0.291666666667,0.282352941176)
Robin egg blue,00CCCC,rgb=(0.0,0.8,0.8),hsl=(0.5,1.0,0.4),hsv=(0.5,1.0,0.8)
Rose bonbon,F9429E,rgb=(0.976470588235,0.258823529412,0.619607843137),hsl=(0.91621129326,0.938461538462,0.617647058824),hsv=(0.91621129326,0.734939759036,0.976470588235)
Rose gold,B76E79,rgb=(0.717647058824,0.43137254902,0.474509803922),hsl=(0.974885844749,0.336405529954,0.574509803922),hsv=(0.974885844749,0.398907103825,0.717647058824)
Rose madder,E32636,rgb=(0.890196078431,0.149019607843,0.211764705882),hsl=(0.985890652557,0.771428571429,0.519607843137),hsv=(0.985890652557,0.832599118943,0.890196078431)
Rose pink,FF66CC,rgb=(1.0,0.4,0.8),hsl=(0.888888888889,1.0,0.7),hsv=(0.888888888889,0.6,1.0)
Rose quartz,AA98A9,rgb=(0.666666666667,0.596078431373,0.662745098039),hsl=(0.842592592593,0.0957446808511,0.63137254902),hsv=(0.842592592593,0.105882352941,0.666666666667)
Rose vale,AB4E52,rgb=(0.670588235294,0.305882352941,0.321568627451),hsl=(0.992831541219,0.373493975904,0.488235294118),hsv=(0.992831541219,0.543859649123,0.670588235294)
Rose,FF007F,rgb=(1.0,0.0,0.498039215686),hsl=(0.916993464052,1.0,0.5),hsv=(0.916993464052,1.0,1.0)
Rosewood,65000B,rgb=(0.396078431373,0.0,0.043137254902),hsl=(0.981848184818,1.0,0.198039215686),hsv=(0.981848184818,1.0,0.396078431373)
Rosso corsa,D40000,rgb=(0.83137254902,0.0,0.0),hsl=(0.0,1.0,0.41568627451),hsv=(0.0,1.0,0.83137254902)
Royal azure,0038A8,rgb=(0.0,0.219607843137,0.658823529412),hsl=(0.611111111111,1.0,0.329411764706),hsv=(0.611111111111,1.0,0.658823529412)
Royal blue (traditional),002366,rgb=(0.0,0.137254901961,0.4),hsl=(0.609477124183,1.0,0.2),hsv=(0.609477124183,1.0,0.4)
Royal blue (web),4169E1,rgb=(0.254901960784,0.411764705882,0.882352941176),hsl=(0.625,0.727272727273,0.56862745098),hsv=(0.625,0.711111111111,0.882352941176)
Royal fuchsia,CA2C92,rgb=(0.792156862745,0.172549019608,0.572549019608),hsl=(0.892405063291,0.642276422764,0.482352941176),hsv=(0.892405063291,0.782178217822,0.792156862745)
Royal purple,7851A9,rgb=(0.470588235294,0.317647058824,0.662745098039),hsl=(0.74053030303,0.352,0.490196078431),hsv=(0.74053030303,0.520710059172,0.662745098039)
Ruby,E0115F,rgb=(0.878431372549,0.0666666666667,0.372549019608),hsl=(0.937198067633,0.858921161826,0.472549019608),hsv=(0.937198067633,0.924107142857,0.878431372549)
Ruddy brown,BB6528,rgb=(0.733333333333,0.396078431373,0.156862745098),hsl=(0.0691609977324,0.647577092511,0.445098039216),hsv=(0.0691609977324,0.786096256684,0.733333333333)
Ruddy pink,E18E96,rgb=(0.882352941176,0.556862745098,0.588235294118),hsl=(0.983935742972,0.58041958042,0.719607843137),hsv=(0.983935742972,0.368888888889,0.882352941176)
Ruddy,FF0028,rgb=(1.0,0.0,0.156862745098),hsl=(0.97385620915,1.0,0.5),hsv=(0.97385620915,1.0,1.0)
Rufous,A81C07,rgb=(0.658823529412,0.109803921569,0.0274509803922),hsl=(0.0217391304348,0.92,0.343137254902),hsv=(0.0217391304348,0.958333333333,0.658823529412)
Russet,80461B,rgb=(0.501960784314,0.274509803922,0.105882352941),hsl=(0.0709570957096,0.651612903226,0.303921568627),hsv=(0.0709570957096,0.7890625,0.501960784314)
Rust,B7410E,rgb=(0.717647058824,0.254901960784,0.0549019607843),hsl=(0.0502958579882,0.857868020305,0.386274509804),hsv=(0.0502958579882,0.92349726776,0.717647058824)
Saddle brown,8B4513,rgb=(0.545098039216,0.270588235294,0.0745098039216),hsl=(0.0694444444444,0.759493670886,0.309803921569),hsv=(0.0694444444444,0.863309352518,0.545098039216)
Safety orange (blaze orange),FF6700,rgb=(1.0,0.403921568627,0.0),hsl=(0.0673202614379,1.0,0.5),hsv=(0.0673202614379,1.0,1.0)
Saffron,F4C430,rgb=(0.956862745098,0.76862745098,0.188235294118),hsl=(0.125850340136,0.899082568807,0.572549019608),hsv=(0.125850340136,0.803278688525,0.956862745098)
Salmon,FF8C69,rgb=(1.0,0.549019607843,0.411764705882),hsl=(0.0388888888889,1.0,0.705882352941),hsv=(0.0388888888889,0.588235294118,1.0)
Sand dune,967117,rgb=(0.588235294118,0.443137254902,0.0901960784314),hsl=(0.11811023622,0.734104046243,0.339215686275),hsv=(0.11811023622,0.846666666667,0.588235294118)
Sand,C2B280,rgb=(0.760784313725,0.698039215686,0.501960784314),hsl=(0.126262626263,0.351063829787,0.63137254902),hsv=(0.126262626263,0.340206185567,0.760784313725)
Sandstorm,ECD540,rgb=(0.925490196078,0.835294117647,0.250980392157),hsl=(0.144379844961,0.819047619048,0.588235294118),hsv=(0.144379844961,0.728813559322,0.925490196078)
Sandy brown,F4A460,rgb=(0.956862745098,0.643137254902,0.376470588235),hsl=(0.0765765765766,0.870588235294,0.666666666667),hsv=(0.0765765765766,0.606557377049,0.956862745098)
Sandy taupe,967117,rgb=(0.588235294118,0.443137254902,0.0901960784314),hsl=(0.11811023622,0.734104046243,0.339215686275),hsv=(0.11811023622,0.846666666667,0.588235294118)
Sangria,92000A,rgb=(0.572549019608,0.0,0.0392156862745),hsl=(0.988584474886,1.0,0.286274509804),hsv=(0.988584474886,1.0,0.572549019608)
Sap green,507D2A,rgb=(0.313725490196,0.490196078431,0.164705882353),hsl=(0.25702811245,0.497005988024,0.327450980392),hsv=(0.25702811245,0.664,0.490196078431)
Sapphire,082567,rgb=(0.0313725490196,0.145098039216,0.403921568627),hsl=(0.615789473684,0.855855855856,0.217647058824),hsv=(0.615789473684,0.922330097087,0.403921568627)
Satiheengold,CBA135,rgb=(0.796078431373,0.63137254902,0.207843137255),hsl=(0.12,0.590551181102,0.501960784314),hsv=(0.12,0.738916256158,0.796078431373)
Scarlet,FF2400,rgb=(1.0,0.141176470588,0.0),hsl=(0.0235294117647,1.0,0.5),hsv=(0.0235294117647,1.0,1.0)
School bus yellow,FFD800,rgb=(1.0,0.847058823529,0.0),hsl=(0.141176470588,1.0,0.5),hsv=(0.141176470588,1.0,1.0)
Sea green,2E8B57,rgb=(0.180392156863,0.545098039216,0.341176470588),hsl=(0.406810035842,0.502702702703,0.362745098039),hsv=(0.406810035842,0.669064748201,0.545098039216)
Seal brown,321414,rgb=(0.196078431373,0.078431372549,0.078431372549),hsl=(0.0,0.428571428571,0.137254901961),hsv=(0.0,0.6,0.196078431373)
Seashell,FFF5EE,rgb=(1.0,0.960784313725,0.933333333333),hsl=(0.0686274509804,1.0,0.966666666667),hsv=(0.0686274509804,0.0666666666667,1.0)
Selective yellow,FFBA00,rgb=(1.0,0.729411764706,0.0),hsl=(0.121568627451,1.0,0.5),hsv=(0.121568627451,1.0,1.0)
Sepia,704214,rgb=(0.439215686275,0.258823529412,0.078431372549),hsl=(0.0833333333333,0.69696969697,0.258823529412),hsv=(0.0833333333333,0.821428571429,0.439215686275)
Shadow,8A795D,rgb=(0.541176470588,0.474509803922,0.364705882353),hsl=(0.103703703704,0.194805194805,0.452941176471),hsv=(0.103703703704,0.326086956522,0.541176470588)
Shocking pink,FC0FC0,rgb=(0.988235294118,0.0588235294118,0.752941176471),hsl=(0.87552742616,0.975308641975,0.523529411765),hsv=(0.87552742616,0.940476190476,0.988235294118)
Sienna,882D17,rgb=(0.533333333333,0.176470588235,0.0901960784314),hsl=(0.0324483775811,0.710691823899,0.311764705882),hsv=(0.0324483775811,0.830882352941,0.533333333333)
Silver,C0C0C0,rgb=(0.752941176471,0.752941176471,0.752941176471),hsl=(-,-,0.752941176471),hsv=(-,-,0.752941176471)
Sinopia,CB410B,rgb=(0.796078431373,0.254901960784,0.043137254902),hsl=(0.046875,0.897196261682,0.419607843137),hsv=(0.046875,0.945812807882,0.796078431373)
Sky blue,87CEEB,rgb=(0.529411764706,0.807843137255,0.921568627451),hsl=(0.548333333333,0.714285714286,0.725490196078),hsv=(0.548333333333,0.425531914894,0.921568627451)
Sky magenta,CF71AF,rgb=(0.811764705882,0.443137254902,0.686274509804),hsl=(0.890070921986,0.494736842105,0.627450980392),hsv=(0.890070921986,0.454106280193,0.811764705882)
Slate blue,6A5ACD,rgb=(0.41568627451,0.352941176471,0.803921568627),hsl=(0.689855072464,0.53488372093,0.578431372549),hsv=(0.689855072464,0.560975609756,0.803921568627)
Slate gray,708090,rgb=(0.439215686275,0.501960784314,0.564705882353),hsl=(0.583333333333,0.125984251969,0.501960784314),hsv=(0.583333333333,0.222222222222,0.564705882353)
Smalt (Dark powder blue),003399,rgb=(0.0,0.2,0.6),hsl=(0.611111111111,1.0,0.3),hsv=(0.611111111111,1.0,0.6)
Smokey topaz,933D41,rgb=(0.576470588235,0.239215686275,0.254901960784),hsl=(0.992248062016,0.413461538462,0.407843137255),hsv=(0.992248062016,0.585034013605,0.576470588235)
Smoky black,100C08,rgb=(0.0627450980392,0.0470588235294,0.0313725490196),hsl=(0.0833333333333,0.333333333333,0.0470588235294),hsv=(0.0833333333333,0.5,0.0627450980392)
Snow,FFFAFA,rgb=(1.0,0.980392156863,0.980392156863),hsl=(0.0,1.0,0.990196078431),hsv=(0.0,0.0196078431373,1.0)
Splashed white,FEFDFF,rgb=(0.996078431373,0.992156862745,1.0),hsl=(0.75,1.0,0.996078431373),hsv=(0.75,0.0078431372549,1.0)
Spring bud,A7FC00,rgb=(0.654901960784,0.988235294118,0.0),hsl=(0.222883597884,1.0,0.494117647059),hsv=(0.222883597884,1.0,0.988235294118)
Spring green,00FF7F,rgb=(0.0,1.0,0.498039215686),hsl=(0.416339869281,1.0,0.5),hsv=(0.416339869281,1.0,1.0)
Steel blue,4682B4,rgb=(0.274509803922,0.509803921569,0.705882352941),hsl=(0.575757575758,0.44,0.490196078431),hsv=(0.575757575758,0.611111111111,0.705882352941)
Stil de grain yellow,FADA5E,rgb=(0.980392156863,0.854901960784,0.36862745098),hsl=(0.132478632479,0.939759036145,0.674509803922),hsv=(0.132478632479,0.624,0.980392156863)
Stizza,990000,rgb=(0.6,0.0,0.0),hsl=(0.0,1.0,0.3),hsv=(0.0,1.0,0.6)
Straw,E4D96F,rgb=(0.894117647059,0.850980392157,0.435294117647),hsl=(0.150997150997,0.684210526316,0.664705882353),hsv=(0.150997150997,0.513157894737,0.894117647059)
Sunglow,FFCC33,rgb=(1.0,0.8,0.2),hsl=(0.125,1.0,0.6),hsv=(0.125,0.8,1.0)
Sunset,FAD6A5,rgb=(0.980392156863,0.839215686275,0.647058823529),hsl=(0.0960784313725,0.894736842105,0.813725490196),hsv=(0.0960784313725,0.34,0.980392156863)
Tan,D2B48C,rgb=(0.823529411765,0.705882352941,0.549019607843),hsl=(0.0952380952381,0.4375,0.686274509804),hsv=(0.0952380952381,0.333333333333,0.823529411765)
Tangelo,F94D00,rgb=(0.976470588235,0.301960784314,0.0),hsl=(0.0515394912985,1.0,0.488235294118),hsv=(0.0515394912985,1.0,0.976470588235)
Tangerine yellow,FFCC00,rgb=(1.0,0.8,0.0),hsl=(0.133333333333,1.0,0.5),hsv=(0.133333333333,1.0,1.0)
Tangerine,F28500,rgb=(0.949019607843,0.521568627451,0.0),hsl=(0.0915977961433,1.0,0.474509803922),hsv=(0.0915977961433,1.0,0.949019607843)
Taupe,483C32,rgb=(0.282352941176,0.235294117647,0.196078431373),hsl=(0.0757575757576,0.180327868852,0.239215686275),hsv=(0.0757575757576,0.305555555556,0.282352941176)
Tea green,D0F0C0,rgb=(0.81568627451,0.941176470588,0.752941176471),hsl=(0.277777777778,0.615384615385,0.847058823529),hsv=(0.277777777778,0.2,0.941176470588)
Tea rose (orange),F88379,rgb=(0.972549019608,0.513725490196,0.474509803922),hsl=(0.0131233595801,0.900709219858,0.723529411765),hsv=(0.0131233595801,0.512096774194,0.972549019608)
Teal blue,367588,rgb=(0.211764705882,0.458823529412,0.533333333333),hsl=(0.538617886179,0.431578947368,0.372549019608),hsv=(0.538617886179,0.602941176471,0.533333333333)
Teal green,006D5B,rgb=(0.0,0.427450980392,0.356862745098),hsl=(0.47247706422,1.0,0.213725490196),hsv=(0.47247706422,1.0,0.427450980392)
Teal,008080,rgb=(0.0,0.501960784314,0.501960784314),hsl=(0.5,1.0,0.250980392157),hsv=(0.5,1.0,0.501960784314)
Tenn (Tawny),CD5700,rgb=(0.803921568627,0.341176470588,0.0),hsl=(0.0707317073171,1.0,0.401960784314),hsv=(0.0707317073171,1.0,0.803921568627)
Terra cotta,E2725B,rgb=(0.886274509804,0.447058823529,0.356862745098),hsl=(0.0283950617284,0.699481865285,0.621568627451),hsv=(0.0283950617284,0.597345132743,0.886274509804)
Thistle,D8BFD8,rgb=(0.847058823529,0.749019607843,0.847058823529),hsl=(0.833333333333,0.242718446602,0.798039215686),hsv=(0.833333333333,0.115740740741,0.847058823529)
Thulian pink,DE6FA1,rgb=(0.870588235294,0.435294117647,0.63137254902),hsl=(0.924924924925,0.627118644068,0.652941176471),hsv=(0.924924924925,0.5,0.870588235294)
Tiffany Blue,0ABAB5,rgb=(0.0392156862745,0.729411764706,0.709803921569),hsl=(0.495265151515,0.897959183673,0.38431372549),hsv=(0.495265151515,0.94623655914,0.729411764706)
Timberwolf,DBD7D2,rgb=(0.858823529412,0.843137254902,0.823529411765),hsl=(0.0925925925926,0.111111111111,0.841176470588),hsv=(0.0925925925926,0.041095890411,0.858823529412)
Titanium yellow,EEE600,rgb=(0.933333333333,0.901960784314,0.0),hsl=(0.16106442577,1.0,0.466666666667),hsv=(0.16106442577,1.0,0.933333333333)
Tomato,FF6347,rgb=(1.0,0.388235294118,0.278431372549),hsl=(0.0253623188406,1.0,0.639215686275),hsv=(0.0253623188406,0.721568627451,1.0)
Trolley Grey,808080,rgb=(0.501960784314,0.501960784314,0.501960784314),hsl=(-,-,0.501960784314),hsv=(-,-,0.501960784314)
True Blue,0073CF,rgb=(0.0,0.450980392157,0.811764705882),hsl=(0.574074074074,1.0,0.405882352941),hsv=(0.574074074074,1.0,0.811764705882)
Tumbleweed,DEAA88,rgb=(0.870588235294,0.666666666667,0.533333333333),hsl=(0.0658914728682,0.565789473684,0.701960784314),hsv=(0.0658914728682,0.387387387387,0.870588235294)
Turquoise blue,00FFEF,rgb=(0.0,1.0,0.937254901961),hsl=(0.48954248366,1.0,0.5),hsv=(0.48954248366,1.0,1.0)
Turquoise green,A0D6B4,rgb=(0.627450980392,0.839215686275,0.705882352941),hsl=(0.395061728395,0.397058823529,0.733333333333),hsv=(0.395061728395,0.252336448598,0.839215686275)
Turquoise,30D5C8,rgb=(0.188235294118,0.835294117647,0.78431372549),hsl=(0.486868686869,0.66265060241,0.511764705882),hsv=(0.486868686869,0.774647887324,0.835294117647)
Tuscan red,66424D,rgb=(0.4,0.258823529412,0.301960784314),hsl=(0.949074074074,0.214285714286,0.329411764706),hsv=(0.949074074074,0.352941176471,0.4)
Twilight lavender,8A496B,rgb=(0.541176470588,0.286274509804,0.419607843137),hsl=(0.912820512821,0.308056872038,0.413725490196),hsv=(0.912820512821,0.471014492754,0.541176470588)
UA blue,0033AA,rgb=(0.0,0.2,0.666666666667),hsl=(0.616666666667,1.0,0.333333333333),hsv=(0.616666666667,1.0,0.666666666667)
UA red,D9004C,rgb=(0.850980392157,0.0,0.298039215686),hsl=(0.941628264209,1.0,0.425490196078),hsv=(0.941628264209,1.0,0.850980392157)
Ube,8878C3,rgb=(0.533333333333,0.470588235294,0.764705882353),hsl=(0.702222222222,0.384615384615,0.617647058824),hsv=(0.702222222222,0.384615384615,0.764705882353)
Ultra pink,FF6FFF,rgb=(1.0,0.435294117647,1.0),hsl=(0.833333333333,1.0,0.717647058824),hsv=(0.833333333333,0.564705882353,1.0)
Ultramarine blue,4166F5,rgb=(0.254901960784,0.4,0.960784313725),hsl=(0.632407407407,0.9,0.607843137255),hsv=(0.632407407407,0.734693877551,0.960784313725)
Ultramarine,120A8F,rgb=(0.0705882352941,0.0392156862745,0.560784313725),hsl=(0.676691729323,0.869281045752,0.3),hsv=(0.676691729323,0.93006993007,0.560784313725)
Umber,635147,rgb=(0.388235294118,0.317647058824,0.278431372549),hsl=(0.0595238095238,0.164705882353,0.333333333333),hsv=(0.0595238095238,0.282828282828,0.388235294118)
Unmellow Yellow,FFFF66,rgb=(1.0,1.0,0.4),hsl=(0.166666666667,1.0,0.7),hsv=(0.166666666667,0.6,1.0)
Upsdell red,AE2029,rgb=(0.682352941176,0.125490196078,0.160784313725),hsl=(0.989436619718,0.68932038835,0.403921568627),hsv=(0.989436619718,0.816091954023,0.682352941176)
Urobilin,E1AD21,rgb=(0.882352941176,0.678431372549,0.129411764706),hsl=(0.121527777778,0.761904761905,0.505882352941),hsv=(0.121527777778,0.853333333333,0.882352941176)
Vanilla,F3E5AB,rgb=(0.952941176471,0.898039215686,0.670588235294),hsl=(0.134259259259,0.75,0.811764705882),hsv=(0.134259259259,0.296296296296,0.952941176471)
Vegas gold,C5B358,rgb=(0.772549019608,0.701960784314,0.345098039216),hsl=(0.139143730887,0.484444444444,0.558823529412),hsv=(0.139143730887,0.553299492386,0.772549019608)
Verdigris,43B3AE,rgb=(0.262745098039,0.701960784314,0.682352941176),hsl=(0.49255952381,0.455284552846,0.482352941176),hsv=(0.49255952381,0.625698324022,0.701960784314)
Vermilion,E34234,rgb=(0.890196078431,0.258823529412,0.203921568627),hsl=(0.0133333333333,0.757575757576,0.547058823529),hsv=(0.0133333333333,0.770925110132,0.890196078431)
Veronica,A020F0,rgb=(0.627450980392,0.125490196078,0.941176470588),hsl=(0.769230769231,0.873949579832,0.533333333333),hsv=(0.769230769231,0.866666666667,0.941176470588)
Violet (color wheel),7F00FF,rgb=(0.498039215686,0.0,1.0),hsl=(0.749673202614,1.0,0.5),hsv=(0.749673202614,1.0,1.0)
Violet (RYB),8601AF,rgb=(0.525490196078,0.00392156862745,0.686274509804),hsl=(0.794061302682,0.988636363636,0.345098039216),hsv=(0.794061302682,0.994285714286,0.686274509804)
Violet (web),EE82EE,rgb=(0.933333333333,0.509803921569,0.933333333333),hsl=(0.833333333333,0.760563380282,0.721568627451),hsv=(0.833333333333,0.453781512605,0.933333333333)
Violet,8F00FF,rgb=(0.560784313725,0.0,1.0),hsl=(0.760130718954,1.0,0.5),hsv=(0.760130718954,1.0,1.0)
Viridian,40826D,rgb=(0.250980392157,0.509803921569,0.427450980392),hsl=(0.44696969697,0.340206185567,0.380392156863),hsv=(0.44696969697,0.507692307692,0.509803921569)
Vivid auburn,922724,rgb=(0.572549019608,0.152941176471,0.141176470588),hsl=(0.00454545454545,0.604395604396,0.356862745098),hsv=(0.00454545454545,0.753424657534,0.572549019608)
Vivid burgundy,9F1D35,rgb=(0.623529411765,0.113725490196,0.207843137255),hsl=(0.969230769231,0.691489361702,0.36862745098),hsv=(0.969230769231,0.817610062893,0.623529411765)
Vivid cerise,DA1D81,rgb=(0.854901960784,0.113725490196,0.505882352941),hsl=(0.911816578483,0.765182186235,0.48431372549),hsv=(0.911816578483,0.866972477064,0.854901960784)
Vivid tangerine,FFA089,rgb=(1.0,0.627450980392,0.537254901961),hsl=(0.0324858757062,1.0,0.76862745098),hsv=(0.0324858757062,0.462745098039,1.0)
Vivid violet,9F00FF,rgb=(0.623529411765,0.0,1.0),hsl=(0.770588235294,1.0,0.5),hsv=(0.770588235294,1.0,1.0)
Warm black,004242,rgb=(0.0,0.258823529412,0.258823529412),hsl=(0.5,1.0,0.129411764706),hsv=(0.5,1.0,0.258823529412)
Wenge,645452,rgb=(0.392156862745,0.329411764706,0.321568627451),hsl=(0.0185185185185,0.0989010989011,0.356862745098),hsv=(0.0185185185185,0.18,0.392156862745)
Wheat,F5DEB3,rgb=(0.960784313725,0.870588235294,0.701960784314),hsl=(0.108585858586,0.767441860465,0.83137254902),hsv=(0.108585858586,0.269387755102,0.960784313725)
White smoke,F5F5F5,rgb=(0.960784313725,0.960784313725,0.960784313725),hsl=(-,-,0.960784313725),hsv=(-,-,0.960784313725)
White,FFFFFF,rgb=(1.0,1.0,1.0),hsl=(-,-,1.0),hsv=(-,-,1.0)
Wild blue yonder,A2ADD0,rgb=(0.635294117647,0.678431372549,0.81568627451),hsl=(0.626811594203,0.328571428571,0.725490196078),hsv=(0.626811594203,0.221153846154,0.81568627451)
Wild Strawberry,FF43A4,rgb=(1.0,0.262745098039,0.643137254902),hsl=(0.914007092199,1.0,0.63137254902),hsv=(0.914007092199,0.737254901961,1.0)
Wild Watermelon,FC6C85,rgb=(0.988235294118,0.423529411765,0.521568627451),hsl=(0.971064814815,0.96,0.705882352941),hsv=(0.971064814815,0.571428571429,0.988235294118)
Wine,722F37,rgb=(0.447058823529,0.18431372549,0.21568627451),hsl=(0.980099502488,0.416149068323,0.31568627451),hsv=(0.980099502488,0.587719298246,0.447058823529)
Wisteria,C9A0DC,rgb=(0.788235294118,0.627450980392,0.862745098039),hsl=(0.780555555556,0.461538461538,0.745098039216),hsv=(0.780555555556,0.272727272727,0.862745098039)
Yale Blue,0F4D92,rgb=(0.0588235294118,0.301960784314,0.572549019608),hsl=(0.587786259542,0.813664596273,0.31568627451),hsv=(0.587786259542,0.897260273973,0.572549019608)
Yellow (Munsell),EFCC00,rgb=(0.937254901961,0.8,0.0),hsl=(0.142259414226,1.0,0.46862745098),hsv=(0.142259414226,1.0,0.937254901961)
Yellow (NCS),FFD300,rgb=(1.0,0.827450980392,0.0),hsl=(0.137908496732,1.0,0.5),hsv=(0.137908496732,1.0,1.0)
Yellow (process),FFEF00,rgb=(1.0,0.937254901961,0.0),hsl=(0.156209150327,1.0,0.5),hsv=(0.156209150327,1.0,1.0)
Yellow (RYB),FEFE33,rgb=(0.996078431373,0.996078431373,0.2),hsl=(0.166666666667,0.990243902439,0.598039215686),hsv=(0.166666666667,0.799212598425,0.996078431373)
Yellow,FFFF00,rgb=(1.0,1.0,0.0),hsl=(0.166666666667,1.0,0.5),hsv=(0.166666666667,1.0,1.0)
Yellow-green,9ACD32,rgb=(0.603921568627,0.803921568627,0.196078431373),hsl=(0.221505376344,0.607843137255,0.5),hsv=(0.221505376344,0.756097560976,0.803921568627)
Zaffre,0014A8,rgb=(0.0,0.078431372549,0.658823529412),hsl=(0.646825396825,1.0,0.329411764706),hsv=(0.646825396825,1.0,0.658823529412)
Zinnwaldite brown,2C1608,rgb=(0.172549019608,0.0862745098039,0.0313725490196),hsl=(0.0648148148148,0.692307692308,0.101960784314),hsv=(0.0648148148148,0.818181818182,0.172549019608)
";
    }
}